window.Gleam.initSearch([{"doc":"tallgrass","title":"tallgrass","content":"# tallgrass\n\n[![Package Version](https://img.shields.io/hexpm/v/tallgrass)](https://hex.pm/packages/tallgrass)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/tallgrass/)\n\nThe `tallgrass` package is a Gleam wrapper for the [PokeAPI](https://pokeapi.co) and is installable via hex.\n\n```sh\ngleam add tallgrass\n```\n\nGet started with the examples below. Further documentation can be found at &lt;https://hexdocs.pm/tallgrass&gt;.\n\n## Examples\n\n### Fetching resources by name or ID\n\nThe majority of PokeAPI resources can be fetched directly by either name or ID. Only a few\n(`characteristic`, `contest-effect`, `evolution-chain`, `machine`, and `super-contest-effect`)\nneed to be fetched by ID.\n\n```gleam\nimport tallgrass/client\nimport tallgrass/machine\nimport tallgrass/pokemon\n\nfn example() {\n  let client = client.new()\n\n  // Pokemon can be fetched by name or ID.\n  let assert Ok(ditto) = pokemon.fetch_by_name(client, &quot;ditto&quot;)\n  let assert Ok(ditto) = pokemon.fetch_by_id(client, 132)\n\n  // Machines can only be fetched by ID.\n  let assert Ok(tm_01) = machine.fetch_by_id(client, 2)\n}\n```\n\n### Paginated resources\n\nYou can also fetch (and traverse) paginated resources. The returned resources will only contain\nthe name of the resource (if available) and its corresponding PokeAPI URL.\n\nPagination options (limit and offset) need to be specified for these requests. Specify one\nor both of these options using `client.PaginationOptions`.\n\n```gleam\nimport gleam/list\nimport tallgrass/client.{Limit, Offset, Paginate, with_pagination}\nimport tallgrass/pokemon\n\nfn example() {\n  let client = client.new()\n\n  // default to a limit of 20\n  let assert Ok(page) = client |&gt; pokemon.fetch()\n\n  // or specify a different limit or offset, or both\n  let assert Ok(page) = client |&gt; with_pagination(Limit(100)) |&gt; pokemon.fetch()\n  let assert Ok(page) = client |&gt; with_pagination(Offset(20)) |&gt; pokemon.fetch()\n  let assert Ok(page) = client |&gt; with_pagination(Paginate(limit: 100, offset: 20)) |&gt; pokemon.fetch()\n\n  // the returned resources can then be fetched directly\n  let assert Ok(resource) = page.results |&gt; list.first\n  let assert Ok(pokemon) = pokemon.fetch_resource(client, resource)\n\n  // or you can move on to the next or previous page\n  let assert Ok(next_page) = client.next(client, page)\n  let assert Ok(previous_page) = client.previous(client, next_page)\n}\n```\n\n### Caching\n\nEvery request response can be cached so that subsequent requests for the same resource\ncan be served without sending an additional HTTP request.\n\n```gleam\nimport tallgrass/client.{with_cache}\nimport tallgrass/client/cache.{Hours}\nimport tallgrass/pokemon\n\nfn example() {\n  // Initialize a new cache with a unique name and the expiration interval.\n  let assert Ok(cache) = cache.new(&quot;unique-cache-name&quot;, Hours(4))\n  let client = client.new() |&gt; with_cache(cache)\n\n  let assert Ok(ditto) = pokemon.fetch_by_name(client, &quot;ditto&quot;)\n\n  // Subsequent requests will be served from cache/memory instead of the API.\n  let assert Ok(ditto) = pokemon.fetch_by_name(client, &quot;ditto&quot;)\n}\n```\n","url":"index.html"},{"doc":"tallgrass/client/cache","title":"Cache","content":"pub opaque type Cache\n A ready-to-use cache can be initialized by using the `new` function.\n\n # Example\n\n \n let assert Ok(cache) = cache.new(&quot;my-unique-name&quot;)\n let client = client.new() |&gt; with_cache(cache)\n client |&gt; pokemon.fetch()\n \n\nSynonyms:\ntallgrass/client/cache.Cache\ntallgrass/client/cache Cache","url":"tallgrass/client/cache.html#Cache"},{"doc":"tallgrass/client/cache","title":"CacheExpiry","content":"pub type CacheExpiry {\n  Seconds(Int)\n  Minutes(Int)\n  Hours(Int)\n}\n Specifies how often the cache should be expired in seconds, minutes, or hours.\nSeconds(Int)\n\n\nMinutes(Int)\n\n\nHours(Int)\n\n\nSynonyms:\ntallgrass/client/cache.CacheExpiry\ntallgrass/client/cache CacheExpiry","url":"tallgrass/client/cache.html#CacheExpiry"},{"doc":"tallgrass/client/cache","title":"new","content":"pub fn new(\n  name: String,\n  expiry: CacheExpiry,\n) -&gt; Result(Cache, Error)\n Initializes a cache that can be passed to client.with_cache()\n If multiple caches are initialized, the `name` param should be unique in order to avoid ETS runtime errors.\nSynonyms:\ntallgrass/client/cache.new\ntallgrass/client/cache new","url":"tallgrass/client/cache.html#new"},{"doc":"tallgrass/client/cache","title":"shutdown","content":"pub fn shutdown(cache: Cache) -&gt; Nil\n Shuts down the cache and cache flushing process.\n Care should be taken to not pass a shutdown cache to client.with_cache.\nSynonyms:\ntallgrass/client/cache.shutdown\ntallgrass/client/cache shutdown","url":"tallgrass/client/cache.html#shutdown"},{"doc":"tallgrass/client/cache","title":"tallgrass/client/cache","content":" Basic request caching based on Erlang Term Storage (ETS).","url":"tallgrass/client/cache.html"},{"doc":"tallgrass/common/resource","title":"PaginatedResource","content":"pub type PaginatedResource {\n  PaginatedResource(\n    count: Int,\n    next: Option(String),\n    previous: Option(String),\n    results: List(Resource),\n  )\n}\n The type of response returned by paginated endpoints. `count` is the total number of records for that type of resource, `results` is a list of\n fetcheable resources on the current page, and the `next` and `previous` links can be used to traverse the rest of the pages.\nPaginatedResource(\n  count: Int,\n  next: Option(String),\n  previous: Option(String),\n  results: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/common/resource.PaginatedResource\ntallgrass/common/resource PaginatedResource","url":"tallgrass/common/resource.html#PaginatedResource"},{"doc":"tallgrass/common/resource","title":"Resource","content":"pub type Resource {\n  Resource(url: String)\n  NamedResource(url: String, name: String)\n}\n The majority of PokeAPI resources are of type `NamedResource`, however there are a few of type `Resource` that are composed only of a URL.\n Because both variants include a URL, fetching the full resource is simply a matter of passing it to a `fetch_resource` function.\n\n # Example\n\n \n let client = client.new()\n use res &lt;- result.try(client |&gt; pokemon.fetch())\n let assert Ok(resource) = res.results |&gt; list.first\n\n // most resources will take this shape\n let assert NamedResource(url, name) = resource\n\n // matching on both variants is safer\n case resource {\n   NamedResource(url, name) -&gt; {todo} // do something with name\n   Resource(url) -&gt; {todo} // do something with url\n }\n\n // fetch the full resource to get more than just the name and url\n client |&gt; pokemon.fetch_resource(resource)\n \nResource(url: String)\n\n\nNamedResource(url: String, name: String)\n\n\nSynonyms:\ntallgrass/common/resource.Resource\ntallgrass/common/resource Resource","url":"tallgrass/common/resource.html#Resource"},{"doc":"tallgrass/common/resource","title":"tallgrass/common/resource","content":"","url":"tallgrass/common/resource.html"},{"doc":"tallgrass/client","title":"Client","content":"pub opaque type Client\n Client is the basic type used to make requests. Client should be initialized with client.new and provided\n with the desired cache and pagination options via `with_cache` and `with_pagination`.\n\nSynonyms:\ntallgrass/client.Client\ntallgrass/client Client","url":"tallgrass/client.html#Client"},{"doc":"tallgrass/client","title":"PaginationOptions","content":"pub type PaginationOptions {\n  Default\n  Limit(Int)\n  Offset(Int)\n  Paginate(limit: Int, offset: Int)\n}\n Paginated endpoints accept `limit` and `offset` query parameters.\n\n # Example\n\n \n let client = pokemon.new()\n\n // Sets the limit to 100\n client |&gt; with_pagination(Limit(100)) |&gt; pokemon.fetch()\n\n // Sets the offset to 20\n client |&gt; with_pagination(Offset(20)) |&gt; pokemon.fetch()\n\n // Sets the limit to 100 and the offset to 20\n client |&gt; with_pagination(Paginate(100, 20)) |&gt; pokemon.fetch()\n \nDefault\n\n\nLimit(Int)\n\n\nOffset(Int)\n\n\nPaginate(limit: Int, offset: Int)\n\n\nSynonyms:\ntallgrass/client.PaginationOptions\ntallgrass/client PaginationOptions","url":"tallgrass/client.html#PaginationOptions"},{"doc":"tallgrass/client","title":"new","content":"pub fn new() -&gt; Client\n Initializes a Client with no cache and default pagination settings.\nSynonyms:\ntallgrass/client.new\ntallgrass/client new","url":"tallgrass/client.html#new"},{"doc":"tallgrass/client","title":"next","content":"pub fn next(\n  client: Client,\n  page: PaginatedResource,\n) -&gt; Result(PaginatedResource, Error)\n Follows the `next` link of a given `PaginatedResource` and returns an error if the `next` link is `null`.\n\n # Example\n\n \n let client = client.new()\n use res &lt;- result.try(client |&gt; pokemon.fetch())\n client |&gt; client.next(res)\n \nSynonyms:\ntallgrass/client.next\ntallgrass/client next","url":"tallgrass/client.html#next"},{"doc":"tallgrass/client","title":"previous","content":"pub fn previous(\n  client: Client,\n  page: PaginatedResource,\n) -&gt; Result(PaginatedResource, Error)\n Follows the `previous` link of a given `PaginatedResource` and returns an error if the `previous` link is `null`.\n\n # Example\n\n \n let client = client.new()\n use res &lt;- result.try(client |&gt; pokemon.fetch())\n client |&gt; client.previous(res)\n \nSynonyms:\ntallgrass/client.previous\ntallgrass/client previous","url":"tallgrass/client.html#previous"},{"doc":"tallgrass/client","title":"with_cache","content":"pub fn with_cache(client: Client, cache: Cache) -&gt; Client\n Returns a Client with the provided Cache.\nSynonyms:\ntallgrass/client.with_cache\ntallgrass/client with_cache","url":"tallgrass/client.html#with_cache"},{"doc":"tallgrass/client","title":"with_pagination","content":"pub fn with_pagination(\n  client: Client,\n  pagination: PaginationOptions,\n) -&gt; Client\n Returns a Client with the provided pagination options.\nSynonyms:\ntallgrass/client.with_pagination\ntallgrass/client with_pagination","url":"tallgrass/client.html#with_pagination"},{"doc":"tallgrass/client","title":"tallgrass/client","content":"","url":"tallgrass/client.html"},{"doc":"tallgrass/berry","title":"Berry","content":"pub type Berry {\n  Berry(\n    id: Int,\n    name: String,\n    growth_time: Int,\n    max_harvest: Int,\n    natural_gift_power: Int,\n    size: Int,\n    smoothness: Int,\n    soil_dryness: Int,\n    firmness: Resource,\n    flavors: List(BerryFlavorMap),\n    item: Resource,\n    natural_gift_type: Resource,\n  )\n}\n\nBerry(\n  id: Int,\n  name: String,\n  growth_time: Int,\n  max_harvest: Int,\n  natural_gift_power: Int,\n  size: Int,\n  smoothness: Int,\n  soil_dryness: Int,\n  firmness: Resource,\n  flavors: List(BerryFlavorMap),\n  item: Resource,\n  natural_gift_type: Resource,\n)\n\n\nSynonyms:\ntallgrass/berry.Berry\ntallgrass/berry Berry","url":"tallgrass/berry.html#Berry"},{"doc":"tallgrass/berry","title":"BerryFlavorMap","content":"pub type BerryFlavorMap {\n  BerryFlavorMap(potency: Int, flavor: Resource)\n}\n\nBerryFlavorMap(potency: Int, flavor: Resource)\n\n\nSynonyms:\ntallgrass/berry.BerryFlavorMap\ntallgrass/berry BerryFlavorMap","url":"tallgrass/berry.html#BerryFlavorMap"},{"doc":"tallgrass/berry","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of berry resources.\n\n # Example\n\n \n let result = berry.new() |&gt; berry.fetch()\n \nSynonyms:\ntallgrass/berry.fetch\ntallgrass/berry fetch","url":"tallgrass/berry.html#fetch"},{"doc":"tallgrass/berry","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Berry, Error)\n Fetches a berry given the berry ID.\n\n # Example\n\n \n let result = berry.new() |&gt; berry.fetch_by_id(1)\n \nSynonyms:\ntallgrass/berry.fetch_by_id\ntallgrass/berry fetch_by_id","url":"tallgrass/berry.html#fetch_by_id"},{"doc":"tallgrass/berry","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Berry, Error)\n Fetches a berry given the berry name.\n\n # Example\n\n \n let result = berry.new() |&gt; berry.fetch_by_name(&quot;cheri&quot;)\n \nSynonyms:\ntallgrass/berry.fetch_by_name\ntallgrass/berry fetch_by_name","url":"tallgrass/berry.html#fetch_by_name"},{"doc":"tallgrass/berry","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Berry, Error)\n Fetches a berry given a berry resource.\n\n # Example\n\n \n let client = berry.new()\n use res &lt;- result.try(client |&gt; berry.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; berry.fetch_resource(first)\n \nSynonyms:\ntallgrass/berry.fetch_resource\ntallgrass/berry fetch_resource","url":"tallgrass/berry.html#fetch_resource"},{"doc":"tallgrass/berry","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/berry.new\ntallgrass/berry new","url":"tallgrass/berry.html#new"},{"doc":"tallgrass/berry","title":"tallgrass/berry","content":"","url":"tallgrass/berry.html"},{"doc":"tallgrass/common/name","title":"Name","content":"pub type Name {\n  Name(name: String, language: Resource)\n}\n\nName(name: String, language: Resource)\n\n\nSynonyms:\ntallgrass/common/name.Name\ntallgrass/common/name Name","url":"tallgrass/common/name.html#Name"},{"doc":"tallgrass/common/name","title":"tallgrass/common/name","content":"","url":"tallgrass/common/name.html"},{"doc":"tallgrass/berry/firmness","title":"BerryFirmness","content":"pub type BerryFirmness {\n  BerryFirmness(\n    id: Int,\n    name: String,\n    berries: List(Resource),\n    names: List(Name),\n  )\n}\n\nBerryFirmness(\n  id: Int,\n  name: String,\n  berries: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/berry/firmness.BerryFirmness\ntallgrass/berry/firmness BerryFirmness","url":"tallgrass/berry/firmness.html#BerryFirmness"},{"doc":"tallgrass/berry/firmness","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of berry firmness resources.\n\n # Example\n\n \n let result = firmness.new() |&gt; firmness.fetch()\n \nSynonyms:\ntallgrass/berry/firmness.fetch\ntallgrass/berry/firmness fetch","url":"tallgrass/berry/firmness.html#fetch"},{"doc":"tallgrass/berry/firmness","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(BerryFirmness, Error)\n Fetches a berry firmness given the berry firmness ID.\n\n # Example\n\n \n let result = firmness.new() |&gt; firmness.fetch_by_id(1)\n \nSynonyms:\ntallgrass/berry/firmness.fetch_by_id\ntallgrass/berry/firmness fetch_by_id","url":"tallgrass/berry/firmness.html#fetch_by_id"},{"doc":"tallgrass/berry/firmness","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(BerryFirmness, Error)\n Fetches a berry firmness given the berry firmness name.\n\n # Example\n\n \n let result = firmness.new() |&gt; firmness.fetch_by_name(&quot;very-soft&quot;)\n \nSynonyms:\ntallgrass/berry/firmness.fetch_by_name\ntallgrass/berry/firmness fetch_by_name","url":"tallgrass/berry/firmness.html#fetch_by_name"},{"doc":"tallgrass/berry/firmness","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(BerryFirmness, Error)\n Fetches a berry firmness given a berry firmness resource.\n\n # Example\n\n \n let client = firmness.new()\n use res &lt;- result.try(client |&gt; firmness.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; firmness.fetch_resource(first)\n \nSynonyms:\ntallgrass/berry/firmness.fetch_resource\ntallgrass/berry/firmness fetch_resource","url":"tallgrass/berry/firmness.html#fetch_resource"},{"doc":"tallgrass/berry/firmness","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/berry/firmness.new\ntallgrass/berry/firmness new","url":"tallgrass/berry/firmness.html#new"},{"doc":"tallgrass/berry/firmness","title":"tallgrass/berry/firmness","content":"","url":"tallgrass/berry/firmness.html"},{"doc":"tallgrass/berry/flavor","title":"BerryFlavor","content":"pub type BerryFlavor {\n  BerryFlavor(\n    id: Int,\n    name: String,\n    berries: List(FlavorBerryMap),\n    contest_type: Resource,\n    names: List(Name),\n  )\n}\n\nBerryFlavor(\n  id: Int,\n  name: String,\n  berries: List(FlavorBerryMap),\n  contest_type: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/berry/flavor.BerryFlavor\ntallgrass/berry/flavor BerryFlavor","url":"tallgrass/berry/flavor.html#BerryFlavor"},{"doc":"tallgrass/berry/flavor","title":"FlavorBerryMap","content":"pub type FlavorBerryMap {\n  FlavorBerryMap(potency: Int, berry: Resource)\n}\n\nFlavorBerryMap(potency: Int, berry: Resource)\n\n\nSynonyms:\ntallgrass/berry/flavor.FlavorBerryMap\ntallgrass/berry/flavor FlavorBerryMap","url":"tallgrass/berry/flavor.html#FlavorBerryMap"},{"doc":"tallgrass/berry/flavor","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of berry flavor resources.\n\n # Example\n\n \n let result = flavor.new() |&gt; flavor.fetch()\n \nSynonyms:\ntallgrass/berry/flavor.fetch\ntallgrass/berry/flavor fetch","url":"tallgrass/berry/flavor.html#fetch"},{"doc":"tallgrass/berry/flavor","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(BerryFlavor, Error)\n Fetches a berry flavor given the berry flavor ID.\n\n # Example\n\n \n let result = flavor.new() |&gt; flavor.fetch_by_id(1)\n \nSynonyms:\ntallgrass/berry/flavor.fetch_by_id\ntallgrass/berry/flavor fetch_by_id","url":"tallgrass/berry/flavor.html#fetch_by_id"},{"doc":"tallgrass/berry/flavor","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(BerryFlavor, Error)\n Fetches a berry flavor given the berry flavor name.\n\n # Example\n\n \n let result = flavor.new() |&gt; flavor.fetch_by_name(&quot;spicy&quot;)\n \nSynonyms:\ntallgrass/berry/flavor.fetch_by_name\ntallgrass/berry/flavor fetch_by_name","url":"tallgrass/berry/flavor.html#fetch_by_name"},{"doc":"tallgrass/berry/flavor","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(BerryFlavor, Error)\n Fetches a berry flavor given a berry flavor resource.\n\n # Example\n\n \n let client = flavor.new()\n use res &lt;- result.try(client |&gt; flavor.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; flavor.fetch_resource(first)\n \nSynonyms:\ntallgrass/berry/flavor.fetch_resource\ntallgrass/berry/flavor fetch_resource","url":"tallgrass/berry/flavor.html#fetch_resource"},{"doc":"tallgrass/berry/flavor","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/berry/flavor.new\ntallgrass/berry/flavor new","url":"tallgrass/berry/flavor.html#new"},{"doc":"tallgrass/berry/flavor","title":"tallgrass/berry/flavor","content":"","url":"tallgrass/berry/flavor.html"},{"doc":"tallgrass/common/description","title":"Description","content":"pub type Description {\n  Description(text: String, language: Resource)\n}\n\nDescription(text: String, language: Resource)\n\n\nSynonyms:\ntallgrass/common/description.Description\ntallgrass/common/description Description","url":"tallgrass/common/description.html#Description"},{"doc":"tallgrass/common/description","title":"tallgrass/common/description","content":"","url":"tallgrass/common/description.html"},{"doc":"tallgrass/common/effect","title":"Effect","content":"pub type Effect {\n  Effect(effect: String, language: Resource)\n}\n\nEffect(effect: String, language: Resource)\n\n\nSynonyms:\ntallgrass/common/effect.Effect\ntallgrass/common/effect Effect","url":"tallgrass/common/effect.html#Effect"},{"doc":"tallgrass/common/effect","title":"VerboseEffect","content":"pub type VerboseEffect {\n  VerboseEffect(\n    effect: String,\n    short_effect: String,\n    language: Resource,\n  )\n}\n\nVerboseEffect(\n  effect: String,\n  short_effect: String,\n  language: Resource,\n)\n\n\nSynonyms:\ntallgrass/common/effect.VerboseEffect\ntallgrass/common/effect VerboseEffect","url":"tallgrass/common/effect.html#VerboseEffect"},{"doc":"tallgrass/common/effect","title":"tallgrass/common/effect","content":"","url":"tallgrass/common/effect.html"},{"doc":"tallgrass/common/flavor_text","title":"FlavorText","content":"pub type FlavorText {\n  FlavorText(text: String, language: Resource)\n}\n\nFlavorText(text: String, language: Resource)\n\n\nSynonyms:\ntallgrass/common/flavor_text.FlavorText\ntallgrass/common/flavor_text FlavorText","url":"tallgrass/common/flavor_text.html#FlavorText"},{"doc":"tallgrass/common/flavor_text","title":"FlavorTextVersionGroup","content":"pub type FlavorTextVersionGroup {\n  FlavorTextVersionGroup(\n    text: String,\n    language: Resource,\n    version_group: Resource,\n  )\n}\n\nFlavorTextVersionGroup(\n  text: String,\n  language: Resource,\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/common/flavor_text.FlavorTextVersionGroup\ntallgrass/common/flavor_text FlavorTextVersionGroup","url":"tallgrass/common/flavor_text.html#FlavorTextVersionGroup"},{"doc":"tallgrass/common/flavor_text","title":"tallgrass/common/flavor_text","content":"","url":"tallgrass/common/flavor_text.html"},{"doc":"tallgrass/common/generation","title":"GenerationGameIndex","content":"pub type GenerationGameIndex {\n  GenerationGameIndex(index: Int, generation: Resource)\n}\n\nGenerationGameIndex(index: Int, generation: Resource)\n\n\nSynonyms:\ntallgrass/common/generation.GenerationGameIndex\ntallgrass/common/generation GenerationGameIndex","url":"tallgrass/common/generation.html#GenerationGameIndex"},{"doc":"tallgrass/common/generation","title":"tallgrass/common/generation","content":"","url":"tallgrass/common/generation.html"},{"doc":"tallgrass/common/pokemon_type","title":"PokemonType","content":"pub type PokemonType {\n  PokemonType(slot: Int, pokemon_type: Resource)\n}\n\nPokemonType(slot: Int, pokemon_type: Resource)\n\n\nSynonyms:\ntallgrass/common/pokemon_type.PokemonType\ntallgrass/common/pokemon_type PokemonType","url":"tallgrass/common/pokemon_type.html#PokemonType"},{"doc":"tallgrass/common/pokemon_type","title":"tallgrass/common/pokemon_type","content":"","url":"tallgrass/common/pokemon_type.html"},{"doc":"tallgrass/common/version","title":"VersionGameIndex","content":"pub type VersionGameIndex {\n  VersionGameIndex(index: Int, version: Resource)\n}\n\nVersionGameIndex(index: Int, version: Resource)\n\n\nSynonyms:\ntallgrass/common/version.VersionGameIndex\ntallgrass/common/version VersionGameIndex","url":"tallgrass/common/version.html#VersionGameIndex"},{"doc":"tallgrass/common/version","title":"tallgrass/common/version","content":"","url":"tallgrass/common/version.html"},{"doc":"tallgrass/contest/contest_type","title":"ContestType","content":"pub type ContestType {\n  ContestType(\n    id: Int,\n    name: String,\n    berry_flavor: Resource,\n    names: List(Name),\n  )\n}\n\nContestType(\n  id: Int,\n  name: String,\n  berry_flavor: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/contest/contest_type.ContestType\ntallgrass/contest/contest_type ContestType","url":"tallgrass/contest/contest_type.html#ContestType"},{"doc":"tallgrass/contest/contest_type","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of contest type resources.\n\n # Example\n\n \n let result = contest_type.new() |&gt; contest_type.fetch()\n \nSynonyms:\ntallgrass/contest/contest_type.fetch\ntallgrass/contest/contest_type fetch","url":"tallgrass/contest/contest_type.html#fetch"},{"doc":"tallgrass/contest/contest_type","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ContestType, Error)\n Fetches a contest type given the contest type ID.\n\n # Example\n\n \n let result = contest_type.new() |&gt; contest_type.fetch_by_id(1)\n \nSynonyms:\ntallgrass/contest/contest_type.fetch_by_id\ntallgrass/contest/contest_type fetch_by_id","url":"tallgrass/contest/contest_type.html#fetch_by_id"},{"doc":"tallgrass/contest/contest_type","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(ContestType, Error)\n Fetches a contest type given the contest type name.\n\n # Example\n\n \n let result = contest_type.new() |&gt; contest_type.fetch_by_name(&quot;cool&quot;)\n \nSynonyms:\ntallgrass/contest/contest_type.fetch_by_name\ntallgrass/contest/contest_type fetch_by_name","url":"tallgrass/contest/contest_type.html#fetch_by_name"},{"doc":"tallgrass/contest/contest_type","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ContestType, Error)\n Fetches a contest type given a contest type resource.\n\n # Example\n\n \n let client = contest_type.new()\n use res &lt;- result.try(client |&gt; contest_type.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; contest_type.fetch_resource(first)\n \nSynonyms:\ntallgrass/contest/contest_type.fetch_resource\ntallgrass/contest/contest_type fetch_resource","url":"tallgrass/contest/contest_type.html#fetch_resource"},{"doc":"tallgrass/contest/contest_type","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/contest/contest_type.new\ntallgrass/contest/contest_type new","url":"tallgrass/contest/contest_type.html#new"},{"doc":"tallgrass/contest/contest_type","title":"tallgrass/contest/contest_type","content":"","url":"tallgrass/contest/contest_type.html"},{"doc":"tallgrass/contest/effect","title":"ContestEffect","content":"pub type ContestEffect {\n  ContestEffect(\n    id: Int,\n    appeal: Int,\n    jam: Int,\n    effect_entries: List(Effect),\n    flavor_text_entries: List(FlavorText),\n  )\n}\n\nContestEffect(\n  id: Int,\n  appeal: Int,\n  jam: Int,\n  effect_entries: List(Effect),\n  flavor_text_entries: List(FlavorText),\n)\n\n\nSynonyms:\ntallgrass/contest/effect.ContestEffect\ntallgrass/contest/effect ContestEffect","url":"tallgrass/contest/effect.html#ContestEffect"},{"doc":"tallgrass/contest/effect","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of contest effect resources.\n\n # Example\n\n \n let result = effect.new() |&gt; effect.fetch()\n \nSynonyms:\ntallgrass/contest/effect.fetch\ntallgrass/contest/effect fetch","url":"tallgrass/contest/effect.html#fetch"},{"doc":"tallgrass/contest/effect","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ContestEffect, Error)\n Fetches a contest effect given the contest effect ID.\n\n # Example\n\n \n let result = effect.new() |&gt; effect.fetch_by_id(1)\n \nSynonyms:\ntallgrass/contest/effect.fetch_by_id\ntallgrass/contest/effect fetch_by_id","url":"tallgrass/contest/effect.html#fetch_by_id"},{"doc":"tallgrass/contest/effect","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ContestEffect, Error)\n Fetches a contest effect given a contest effect resource.\n\n # Example\n\n \n let client = effect.new()\n use res &lt;- result.try(client |&gt; effect.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; effect.fetch_resource(first)\n \nSynonyms:\ntallgrass/contest/effect.fetch_resource\ntallgrass/contest/effect fetch_resource","url":"tallgrass/contest/effect.html#fetch_resource"},{"doc":"tallgrass/contest/effect","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/contest/effect.new\ntallgrass/contest/effect new","url":"tallgrass/contest/effect.html#new"},{"doc":"tallgrass/contest/effect","title":"tallgrass/contest/effect","content":"","url":"tallgrass/contest/effect.html"},{"doc":"tallgrass/contest/super_contest_effect","title":"SuperContestEffect","content":"pub type SuperContestEffect {\n  SuperContestEffect(\n    id: Int,\n    appeal: Int,\n    flavor_text_entries: List(FlavorText),\n    moves: List(Resource),\n  )\n}\n\nSuperContestEffect(\n  id: Int,\n  appeal: Int,\n  flavor_text_entries: List(FlavorText),\n  moves: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/contest/super_contest_effect.SuperContestEffect\ntallgrass/contest/super_contest_effect SuperContestEffect","url":"tallgrass/contest/super_contest_effect.html#SuperContestEffect"},{"doc":"tallgrass/contest/super_contest_effect","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of super contest effect resources.\n\n # Example\n\n \n let result = super_contest_effect.new() |&gt; super_contest_effect.fetch()\n \nSynonyms:\ntallgrass/contest/super_contest_effect.fetch\ntallgrass/contest/super_contest_effect fetch","url":"tallgrass/contest/super_contest_effect.html#fetch"},{"doc":"tallgrass/contest/super_contest_effect","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(SuperContestEffect, Error)\n Fetches a super contest effect given the super contest effect ID.\n\n # Example\n\n \n let result = super_contest_effect.new() |&gt; super_contest_effect.fetch_by_id(1)\n \nSynonyms:\ntallgrass/contest/super_contest_effect.fetch_by_id\ntallgrass/contest/super_contest_effect fetch_by_id","url":"tallgrass/contest/super_contest_effect.html#fetch_by_id"},{"doc":"tallgrass/contest/super_contest_effect","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(SuperContestEffect, Error)\n Fetches a super contest effect given a super contest effect resource.\n\n # Example\n\n \n let client = super_contest_effect.new()\n use res &lt;- result.try(client |&gt; super_contest_effect.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; super_contest_effect.fetch_resource(first)\n \nSynonyms:\ntallgrass/contest/super_contest_effect.fetch_resource\ntallgrass/contest/super_contest_effect fetch_resource","url":"tallgrass/contest/super_contest_effect.html#fetch_resource"},{"doc":"tallgrass/contest/super_contest_effect","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/contest/super_contest_effect.new\ntallgrass/contest/super_contest_effect new","url":"tallgrass/contest/super_contest_effect.html#new"},{"doc":"tallgrass/contest/super_contest_effect","title":"tallgrass/contest/super_contest_effect","content":"","url":"tallgrass/contest/super_contest_effect.html"},{"doc":"tallgrass/encounter/condition","title":"EncounterCondition","content":"pub type EncounterCondition {\n  EncounterCondition(\n    id: Int,\n    name: String,\n    values: List(Resource),\n    names: List(Name),\n  )\n}\n\nEncounterCondition(\n  id: Int,\n  name: String,\n  values: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/encounter/condition.EncounterCondition\ntallgrass/encounter/condition EncounterCondition","url":"tallgrass/encounter/condition.html#EncounterCondition"},{"doc":"tallgrass/encounter/condition","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of encounter condition resources.\n\n # Example\n\n \n let result = condition |&gt; method.fetch()\n \nSynonyms:\ntallgrass/encounter/condition.fetch\ntallgrass/encounter/condition fetch","url":"tallgrass/encounter/condition.html#fetch"},{"doc":"tallgrass/encounter/condition","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EncounterCondition, Error)\n Fetches an encounter condition given the encounter condition ID.\n\n # Example\n\n \n let result = condition.new() |&gt; condition.fetch_by_id(1)\n \nSynonyms:\ntallgrass/encounter/condition.fetch_by_id\ntallgrass/encounter/condition fetch_by_id","url":"tallgrass/encounter/condition.html#fetch_by_id"},{"doc":"tallgrass/encounter/condition","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(EncounterCondition, Error)\n Fetches an encounter condition given the encounter condition name.\n\n # Example\n\n \n let result = condition.new() |&gt; condition.fetch_by_name(&quot;swarm&quot;)\n \nSynonyms:\ntallgrass/encounter/condition.fetch_by_name\ntallgrass/encounter/condition fetch_by_name","url":"tallgrass/encounter/condition.html#fetch_by_name"},{"doc":"tallgrass/encounter/condition","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EncounterCondition, Error)\n Fetches an encounter condition given an encounter condition resource.\n\n # Example\n\n \n let client = condition.new()\n use res &lt;- result.try(client |&gt; condition.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; condition.fetch_resource(first)\n \nSynonyms:\ntallgrass/encounter/condition.fetch_resource\ntallgrass/encounter/condition fetch_resource","url":"tallgrass/encounter/condition.html#fetch_resource"},{"doc":"tallgrass/encounter/condition","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/encounter/condition.new\ntallgrass/encounter/condition new","url":"tallgrass/encounter/condition.html#new"},{"doc":"tallgrass/encounter/condition","title":"tallgrass/encounter/condition","content":"","url":"tallgrass/encounter/condition.html"},{"doc":"tallgrass/encounter/condition/value","title":"EncounterConditionValue","content":"pub type EncounterConditionValue {\n  EncounterConditionValue(\n    id: Int,\n    name: String,\n    condition: Resource,\n    names: List(Name),\n  )\n}\n\nEncounterConditionValue(\n  id: Int,\n  name: String,\n  condition: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/encounter/condition/value.EncounterConditionValue\ntallgrass/encounter/condition/value EncounterConditionValue","url":"tallgrass/encounter/condition/value.html#EncounterConditionValue"},{"doc":"tallgrass/encounter/condition/value","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of encounter condition value resources.\n\n # Example\n\n \n let result = value |&gt; method.fetch()\n \nSynonyms:\ntallgrass/encounter/condition/value.fetch\ntallgrass/encounter/condition/value fetch","url":"tallgrass/encounter/condition/value.html#fetch"},{"doc":"tallgrass/encounter/condition/value","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EncounterConditionValue, Error)\n Fetches an encounter condition value given the encounter condition value ID.\n\n # Example\n\n \n let result = value.new() |&gt; value.fetch_by_id(1)\n \nSynonyms:\ntallgrass/encounter/condition/value.fetch_by_id\ntallgrass/encounter/condition/value fetch_by_id","url":"tallgrass/encounter/condition/value.html#fetch_by_id"},{"doc":"tallgrass/encounter/condition/value","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(EncounterConditionValue, Error)\n Fetches an encounter condition value given the encounter condition value name.\n\n # Example\n\n \n let result = value.new() |&gt; value.fetch_by_name(&quot;swarm-yes&quot;)\n \nSynonyms:\ntallgrass/encounter/condition/value.fetch_by_name\ntallgrass/encounter/condition/value fetch_by_name","url":"tallgrass/encounter/condition/value.html#fetch_by_name"},{"doc":"tallgrass/encounter/condition/value","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EncounterConditionValue, Error)\n Fetches an encounter condition value given an encounter condition value resource.\n\n # Example\n\n \n let client = value.new()\n use res &lt;- result.try(client |&gt; value.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; value.fetch_resource(first)\n \nSynonyms:\ntallgrass/encounter/condition/value.fetch_resource\ntallgrass/encounter/condition/value fetch_resource","url":"tallgrass/encounter/condition/value.html#fetch_resource"},{"doc":"tallgrass/encounter/condition/value","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/encounter/condition/value.new\ntallgrass/encounter/condition/value new","url":"tallgrass/encounter/condition/value.html#new"},{"doc":"tallgrass/encounter/condition/value","title":"tallgrass/encounter/condition/value","content":"","url":"tallgrass/encounter/condition/value.html"},{"doc":"tallgrass/encounter/method","title":"EncounterMethod","content":"pub type EncounterMethod {\n  EncounterMethod(\n    id: Int,\n    name: String,\n    order: Int,\n    names: List(Name),\n  )\n}\n\nEncounterMethod(\n  id: Int,\n  name: String,\n  order: Int,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/encounter/method.EncounterMethod\ntallgrass/encounter/method EncounterMethod","url":"tallgrass/encounter/method.html#EncounterMethod"},{"doc":"tallgrass/encounter/method","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of encounter method resources.\n\n # Example\n\n \n let result = method |&gt; method.fetch()\n \nSynonyms:\ntallgrass/encounter/method.fetch\ntallgrass/encounter/method fetch","url":"tallgrass/encounter/method.html#fetch"},{"doc":"tallgrass/encounter/method","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EncounterMethod, Error)\n Fetches an encounter method given the encounter method ID.\n\n # Example\n\n \n let result = method.new() |&gt; method.fetch_by_id(1)\n \nSynonyms:\ntallgrass/encounter/method.fetch_by_id\ntallgrass/encounter/method fetch_by_id","url":"tallgrass/encounter/method.html#fetch_by_id"},{"doc":"tallgrass/encounter/method","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(EncounterMethod, Error)\n Fetches an encounter method given the encounter method name.\n\n # Example\n\n \n let result = method.new() |&gt; method.fetch_by_name(&quot;walk&quot;)\n \nSynonyms:\ntallgrass/encounter/method.fetch_by_name\ntallgrass/encounter/method fetch_by_name","url":"tallgrass/encounter/method.html#fetch_by_name"},{"doc":"tallgrass/encounter/method","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EncounterMethod, Error)\n Fetches an encounter method given an encounter method resource.\n\n # Example\n\n \n let client = method.new()\n use res &lt;- result.try(client |&gt; method.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; method.fetch_resource(first)\n \nSynonyms:\ntallgrass/encounter/method.fetch_resource\ntallgrass/encounter/method fetch_resource","url":"tallgrass/encounter/method.html#fetch_resource"},{"doc":"tallgrass/encounter/method","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/encounter/method.new\ntallgrass/encounter/method new","url":"tallgrass/encounter/method.html#new"},{"doc":"tallgrass/encounter/method","title":"tallgrass/encounter/method","content":"","url":"tallgrass/encounter/method.html"},{"doc":"tallgrass/evolution/chain","title":"ChainLink","content":"pub type ChainLink {\n  ChainLink(\n    is_baby: Bool,\n    species: Resource,\n    evolution_details: List(EvolutionDetail),\n  )\n}\n\nChainLink(\n  is_baby: Bool,\n  species: Resource,\n  evolution_details: List(EvolutionDetail),\n)\n\n\nSynonyms:\ntallgrass/evolution/chain.ChainLink\ntallgrass/evolution/chain ChainLink","url":"tallgrass/evolution/chain.html#ChainLink"},{"doc":"tallgrass/evolution/chain","title":"EvolutionChain","content":"pub type EvolutionChain {\n  EvolutionChain(\n    id: Int,\n    baby_trigger_item: Option(Resource),\n    chain: ChainLink,\n  )\n}\n\nEvolutionChain(\n  id: Int,\n  baby_trigger_item: Option(Resource),\n  chain: ChainLink,\n)\n\n\nSynonyms:\ntallgrass/evolution/chain.EvolutionChain\ntallgrass/evolution/chain EvolutionChain","url":"tallgrass/evolution/chain.html#EvolutionChain"},{"doc":"tallgrass/evolution/chain","title":"EvolutionDetail","content":"pub type EvolutionDetail {\n  EvolutionDetail(\n    item: Option(Resource),\n    trigger: Resource,\n    gender: Int,\n    held_item: Option(Resource),\n    known_move: Option(Resource),\n    known_move_type: Option(Resource),\n    location: Option(Resource),\n    min_level: Int,\n    min_happiness: Option(Int),\n    min_beauty: Option(Int),\n    min_affection: Option(Int),\n    needs_overworld_rain: Bool,\n    party_species: Option(Resource),\n    party_type: Option(Resource),\n    relative_physical_stats: Int,\n    time_of_day: String,\n    trade_species: Option(Resource),\n    turn_upside_down: Bool,\n  )\n}\n\nEvolutionDetail(\n  item: Option(Resource),\n  trigger: Resource,\n  gender: Int,\n  held_item: Option(Resource),\n  known_move: Option(Resource),\n  known_move_type: Option(Resource),\n  location: Option(Resource),\n  min_level: Int,\n  min_happiness: Option(Int),\n  min_beauty: Option(Int),\n  min_affection: Option(Int),\n  needs_overworld_rain: Bool,\n  party_species: Option(Resource),\n  party_type: Option(Resource),\n  relative_physical_stats: Int,\n  time_of_day: String,\n  trade_species: Option(Resource),\n  turn_upside_down: Bool,\n)\n\n\nSynonyms:\ntallgrass/evolution/chain.EvolutionDetail\ntallgrass/evolution/chain EvolutionDetail","url":"tallgrass/evolution/chain.html#EvolutionDetail"},{"doc":"tallgrass/evolution/chain","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of evolution chain resources.\n\n # Example\n\n \n let result = chain.new() |&gt; chain.fetch()\n \nSynonyms:\ntallgrass/evolution/chain.fetch\ntallgrass/evolution/chain fetch","url":"tallgrass/evolution/chain.html#fetch"},{"doc":"tallgrass/evolution/chain","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EvolutionChain, Error)\n Fetches an evolution chain given the evolution chain ID.\n\n # Example\n\n \n let result = chain.new() |&gt; chain.fetch_by_id(1)\n \nSynonyms:\ntallgrass/evolution/chain.fetch_by_id\ntallgrass/evolution/chain fetch_by_id","url":"tallgrass/evolution/chain.html#fetch_by_id"},{"doc":"tallgrass/evolution/chain","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EvolutionChain, Error)\n Fetches an evolution chain given an evolution chain resource.\n\n # Example\n\n \n let client = chain.new()\n use res &lt;- result.try(client |&gt; chain.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; chain.fetch_resource(first)\n \nSynonyms:\ntallgrass/evolution/chain.fetch_resource\ntallgrass/evolution/chain fetch_resource","url":"tallgrass/evolution/chain.html#fetch_resource"},{"doc":"tallgrass/evolution/chain","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/evolution/chain.new\ntallgrass/evolution/chain new","url":"tallgrass/evolution/chain.html#new"},{"doc":"tallgrass/evolution/chain","title":"tallgrass/evolution/chain","content":"","url":"tallgrass/evolution/chain.html"},{"doc":"tallgrass/evolution/trigger","title":"EvolutionTrigger","content":"pub type EvolutionTrigger {\n  EvolutionTrigger(\n    id: Int,\n    name: String,\n    names: List(Name),\n    pokemon_species: List(Resource),\n  )\n}\n\nEvolutionTrigger(\n  id: Int,\n  name: String,\n  names: List(Name),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/evolution/trigger.EvolutionTrigger\ntallgrass/evolution/trigger EvolutionTrigger","url":"tallgrass/evolution/trigger.html#EvolutionTrigger"},{"doc":"tallgrass/evolution/trigger","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of evolution trigger resources.\n\n # Example\n\n \n let result = trigger.new() |&gt; trigger.fetch()\n \nSynonyms:\ntallgrass/evolution/trigger.fetch\ntallgrass/evolution/trigger fetch","url":"tallgrass/evolution/trigger.html#fetch"},{"doc":"tallgrass/evolution/trigger","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EvolutionTrigger, Error)\n Fetches an evolution trigger given the evolution trigger ID.\n\n # Example\n\n \n let result = trigger.new() |&gt; trigger.fetch_by_id(1)\n \nSynonyms:\ntallgrass/evolution/trigger.fetch_by_id\ntallgrass/evolution/trigger fetch_by_id","url":"tallgrass/evolution/trigger.html#fetch_by_id"},{"doc":"tallgrass/evolution/trigger","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(EvolutionTrigger, Error)\n Fetches an evolution trigger given the evolution trigger name.\n\n # Example\n\n \n let result = trigger.new() |&gt; trigger.fetch_by_name(&quot;level-up&quot;)\n \nSynonyms:\ntallgrass/evolution/trigger.fetch_by_name\ntallgrass/evolution/trigger fetch_by_name","url":"tallgrass/evolution/trigger.html#fetch_by_name"},{"doc":"tallgrass/evolution/trigger","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EvolutionTrigger, Error)\n Fetches an evolution trigger given an evolution trigger resource.\n\n # Example\n\n \n let client = trigger.new()\n use res &lt;- result.try(client |&gt; trigger.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; trigger.fetch_resource(first)\n \nSynonyms:\ntallgrass/evolution/trigger.fetch_resource\ntallgrass/evolution/trigger fetch_resource","url":"tallgrass/evolution/trigger.html#fetch_resource"},{"doc":"tallgrass/evolution/trigger","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/evolution/trigger.new\ntallgrass/evolution/trigger new","url":"tallgrass/evolution/trigger.html#new"},{"doc":"tallgrass/evolution/trigger","title":"tallgrass/evolution/trigger","content":"","url":"tallgrass/evolution/trigger.html"},{"doc":"tallgrass/game/generation","title":"Generation","content":"pub type Generation {\n  Generation(\n    id: Int,\n    name: String,\n    abilities: List(Resource),\n    main_region: Resource,\n    moves: List(Resource),\n    names: List(Name),\n    pokemon_species: List(Resource),\n    types: List(Resource),\n    version_groups: List(Resource),\n  )\n}\n\nGeneration(\n  id: Int,\n  name: String,\n  abilities: List(Resource),\n  main_region: Resource,\n  moves: List(Resource),\n  names: List(Name),\n  pokemon_species: List(Resource),\n  types: List(Resource),\n  version_groups: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/game/generation.Generation\ntallgrass/game/generation Generation","url":"tallgrass/game/generation.html#Generation"},{"doc":"tallgrass/game/generation","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of generation resources.\n\n # Example\n\n \n let result = generation.new() |&gt; generation.fetch()\n \nSynonyms:\ntallgrass/game/generation.fetch\ntallgrass/game/generation fetch","url":"tallgrass/game/generation.html#fetch"},{"doc":"tallgrass/game/generation","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Generation, Error)\n Fetches a generation given the generation ID.\n\n # Example\n\n \n let result = generation.new() |&gt; generation.fetch_by_id(1)\n \nSynonyms:\ntallgrass/game/generation.fetch_by_id\ntallgrass/game/generation fetch_by_id","url":"tallgrass/game/generation.html#fetch_by_id"},{"doc":"tallgrass/game/generation","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Generation, Error)\n Fetches a generation given the generation name.\n\n # Example\n\n \n let result = generation.new() |&gt; generation.fetch_by_name(&quot;generation-i&quot;)\n \nSynonyms:\ntallgrass/game/generation.fetch_by_name\ntallgrass/game/generation fetch_by_name","url":"tallgrass/game/generation.html#fetch_by_name"},{"doc":"tallgrass/game/generation","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Generation, Error)\n Fetches a generation given a generation resource.\n\n # Example\n\n \n let client = generation.new()\n use res &lt;- result.try(client |&gt; generation.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; generation.fetch_resource(first)\n \nSynonyms:\ntallgrass/game/generation.fetch_resource\ntallgrass/game/generation fetch_resource","url":"tallgrass/game/generation.html#fetch_resource"},{"doc":"tallgrass/game/generation","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/game/generation.new\ntallgrass/game/generation new","url":"tallgrass/game/generation.html#new"},{"doc":"tallgrass/game/generation","title":"tallgrass/game/generation","content":"","url":"tallgrass/game/generation.html"},{"doc":"tallgrass/game/pokedex","title":"Pokedex","content":"pub type Pokedex {\n  Pokedex(\n    id: Int,\n    name: String,\n    is_main_series: Bool,\n    descriptions: List(Description),\n    names: List(Name),\n    pokemon_entries: List(PokemonEntry),\n    region: Resource,\n    version_groups: List(Resource),\n  )\n}\n\nPokedex(\n  id: Int,\n  name: String,\n  is_main_series: Bool,\n  descriptions: List(Description),\n  names: List(Name),\n  pokemon_entries: List(PokemonEntry),\n  region: Resource,\n  version_groups: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/game/pokedex.Pokedex\ntallgrass/game/pokedex Pokedex","url":"tallgrass/game/pokedex.html#Pokedex"},{"doc":"tallgrass/game/pokedex","title":"PokemonEntry","content":"pub type PokemonEntry {\n  PokemonEntry(entry: Int, species: Resource)\n}\n\nPokemonEntry(entry: Int, species: Resource)\n\n\nSynonyms:\ntallgrass/game/pokedex.PokemonEntry\ntallgrass/game/pokedex PokemonEntry","url":"tallgrass/game/pokedex.html#PokemonEntry"},{"doc":"tallgrass/game/pokedex","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokedex resources.\n\n # Example\n\n \n let result = pokedex.new() |&gt; pokedex.fetch()\n \nSynonyms:\ntallgrass/game/pokedex.fetch\ntallgrass/game/pokedex fetch","url":"tallgrass/game/pokedex.html#fetch"},{"doc":"tallgrass/game/pokedex","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Pokedex, Error)\n Fetches a pokedex given the pokedex ID.\n\n # Example\n\n \n let result = pokedex.new() |&gt; pokedex.fetch_by_id(1)\n \nSynonyms:\ntallgrass/game/pokedex.fetch_by_id\ntallgrass/game/pokedex fetch_by_id","url":"tallgrass/game/pokedex.html#fetch_by_id"},{"doc":"tallgrass/game/pokedex","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Pokedex, Error)\n Fetches a pokedex given the pokedex name.\n\n # Example\n\n \n let result = pokedex.new() |&gt; pokedex.fetch_by_name(&quot;kanto&quot;)\n \nSynonyms:\ntallgrass/game/pokedex.fetch_by_name\ntallgrass/game/pokedex fetch_by_name","url":"tallgrass/game/pokedex.html#fetch_by_name"},{"doc":"tallgrass/game/pokedex","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Pokedex, Error)\n Fetches a pokedex given a pokedex resource.\n\n # Example\n\n \n let client = pokedex.new()\n use res &lt;- result.try(client |&gt; pokedex.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pokedex.fetch_resource(first)\n \nSynonyms:\ntallgrass/game/pokedex.fetch_resource\ntallgrass/game/pokedex fetch_resource","url":"tallgrass/game/pokedex.html#fetch_resource"},{"doc":"tallgrass/game/pokedex","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/game/pokedex.new\ntallgrass/game/pokedex new","url":"tallgrass/game/pokedex.html#new"},{"doc":"tallgrass/game/pokedex","title":"tallgrass/game/pokedex","content":"","url":"tallgrass/game/pokedex.html"},{"doc":"tallgrass/game/version","title":"Version","content":"pub type Version {\n  Version(\n    id: Int,\n    name: String,\n    names: List(Name),\n    version_group: Resource,\n  )\n}\n\nVersion(\n  id: Int,\n  name: String,\n  names: List(Name),\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/game/version.Version\ntallgrass/game/version Version","url":"tallgrass/game/version.html#Version"},{"doc":"tallgrass/game/version","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of version resources.\n\n # Example\n\n \n let result = version.new() |&gt; version.fetch()\n \nSynonyms:\ntallgrass/game/version.fetch\ntallgrass/game/version fetch","url":"tallgrass/game/version.html#fetch"},{"doc":"tallgrass/game/version","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Version, Error)\n Fetches a version given the version ID.\n\n # Example\n\n \n let result = version.new() |&gt; version.fetch_by_id(1)\n \nSynonyms:\ntallgrass/game/version.fetch_by_id\ntallgrass/game/version fetch_by_id","url":"tallgrass/game/version.html#fetch_by_id"},{"doc":"tallgrass/game/version","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Version, Error)\n Fetches a version given the version name.\n\n # Example\n\n \n let result = version.new() |&gt; version.fetch_by_name(&quot;red&quot;)\n \nSynonyms:\ntallgrass/game/version.fetch_by_name\ntallgrass/game/version fetch_by_name","url":"tallgrass/game/version.html#fetch_by_name"},{"doc":"tallgrass/game/version","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Version, Error)\n Fetches a version given a version resource.\n\n # Example\n\n \n let client = version.new()\n use res &lt;- result.try(client |&gt; version.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; version.fetch_resource(first)\n \nSynonyms:\ntallgrass/game/version.fetch_resource\ntallgrass/game/version fetch_resource","url":"tallgrass/game/version.html#fetch_resource"},{"doc":"tallgrass/game/version","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/game/version.new\ntallgrass/game/version new","url":"tallgrass/game/version.html#new"},{"doc":"tallgrass/game/version","title":"tallgrass/game/version","content":"","url":"tallgrass/game/version.html"},{"doc":"tallgrass/game/version_group","title":"VersionGroup","content":"pub type VersionGroup {\n  VersionGroup(\n    id: Int,\n    name: String,\n    order: Int,\n    generation: Resource,\n    move_learn_methods: List(Resource),\n    pokedexes: List(Resource),\n    regions: List(Resource),\n    versions: List(Resource),\n  )\n}\n\nVersionGroup(\n  id: Int,\n  name: String,\n  order: Int,\n  generation: Resource,\n  move_learn_methods: List(Resource),\n  pokedexes: List(Resource),\n  regions: List(Resource),\n  versions: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/game/version_group.VersionGroup\ntallgrass/game/version_group VersionGroup","url":"tallgrass/game/version_group.html#VersionGroup"},{"doc":"tallgrass/game/version_group","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of version group resources.\n\n # Example\n\n \n let result = version_group.new() |&gt; version_group.fetch()\n \nSynonyms:\ntallgrass/game/version_group.fetch\ntallgrass/game/version_group fetch","url":"tallgrass/game/version_group.html#fetch"},{"doc":"tallgrass/game/version_group","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(VersionGroup, Error)\n Fetches a version group given the version group ID.\n\n # Example\n\n \n let result = version_group.new() |&gt; version_group.fetch_by_id(1)\n \nSynonyms:\ntallgrass/game/version_group.fetch_by_id\ntallgrass/game/version_group fetch_by_id","url":"tallgrass/game/version_group.html#fetch_by_id"},{"doc":"tallgrass/game/version_group","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(VersionGroup, Error)\n Fetches a version group given the version group name.\n\n # Example\n\n \n let result = version_group.new() |&gt; version_group.fetch_by_name(&quot;red-blue&quot;)\n \nSynonyms:\ntallgrass/game/version_group.fetch_by_name\ntallgrass/game/version_group fetch_by_name","url":"tallgrass/game/version_group.html#fetch_by_name"},{"doc":"tallgrass/game/version_group","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(VersionGroup, Error)\n Fetches a version group given a version group resource.\n\n # Example\n\n \n let client = version_group.new()\n use res &lt;- result.try(client |&gt; version_group.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; version_group.fetch_resource(first)\n \nSynonyms:\ntallgrass/game/version_group.fetch_resource\ntallgrass/game/version_group fetch_resource","url":"tallgrass/game/version_group.html#fetch_resource"},{"doc":"tallgrass/game/version_group","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/game/version_group.new\ntallgrass/game/version_group new","url":"tallgrass/game/version_group.html#new"},{"doc":"tallgrass/game/version_group","title":"tallgrass/game/version_group","content":"","url":"tallgrass/game/version_group.html"},{"doc":"tallgrass/item","title":"Item","content":"pub type Item {\n  Item(\n    id: Int,\n    name: String,\n    cost: Int,\n    fling_power: Option(Int),\n    fling_effect: Option(Resource),\n    attributes: List(Resource),\n    category: Resource,\n    effect_entries: List(VerboseEffect),\n    flavor_text_entries: List(VersionGroupFlavorText),\n    game_indices: List(GenerationGameIndex),\n    names: List(Name),\n    held_by_pokemon: List(ItemHolderPokemon),\n    baby_trigger_for: Option(Resource),\n  )\n}\n\nItem(\n  id: Int,\n  name: String,\n  cost: Int,\n  fling_power: Option(Int),\n  fling_effect: Option(Resource),\n  attributes: List(Resource),\n  category: Resource,\n  effect_entries: List(VerboseEffect),\n  flavor_text_entries: List(VersionGroupFlavorText),\n  game_indices: List(GenerationGameIndex),\n  names: List(Name),\n  held_by_pokemon: List(ItemHolderPokemon),\n  baby_trigger_for: Option(Resource),\n)\n\n\nSynonyms:\ntallgrass/item.Item\ntallgrass/item Item","url":"tallgrass/item.html#Item"},{"doc":"tallgrass/item","title":"ItemHolderPokemon","content":"pub type ItemHolderPokemon {\n  ItemHolderPokemon(\n    pokemon: Resource,\n    version_details: List(ItemHolderPokemonVersionDetail),\n  )\n}\n\nItemHolderPokemon(\n  pokemon: Resource,\n  version_details: List(ItemHolderPokemonVersionDetail),\n)\n\n\nSynonyms:\ntallgrass/item.ItemHolderPokemon\ntallgrass/item ItemHolderPokemon","url":"tallgrass/item.html#ItemHolderPokemon"},{"doc":"tallgrass/item","title":"ItemHolderPokemonVersionDetail","content":"pub type ItemHolderPokemonVersionDetail {\n  ItemHolderPokemonVersionDetail(rarity: Int, version: Resource)\n}\n\nItemHolderPokemonVersionDetail(rarity: Int, version: Resource)\n\n\nSynonyms:\ntallgrass/item.ItemHolderPokemonVersionDetail\ntallgrass/item ItemHolderPokemonVersionDetail","url":"tallgrass/item.html#ItemHolderPokemonVersionDetail"},{"doc":"tallgrass/item","title":"VersionGroupFlavorText","content":"pub type VersionGroupFlavorText {\n  VersionGroupFlavorText(\n    text: String,\n    language: Resource,\n    version_group: Resource,\n  )\n}\n\nVersionGroupFlavorText(\n  text: String,\n  language: Resource,\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/item.VersionGroupFlavorText\ntallgrass/item VersionGroupFlavorText","url":"tallgrass/item.html#VersionGroupFlavorText"},{"doc":"tallgrass/item","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of item resources.\n\n # Example\n\n \n let result = item.new() |&gt; item.fetch()\n \nSynonyms:\ntallgrass/item.fetch\ntallgrass/item fetch","url":"tallgrass/item.html#fetch"},{"doc":"tallgrass/item","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Item, Error)\n Fetches an item given the item ID.\n\n # Example\n\n \n let result = item.new() |&gt; item.fetch_by_id(1)\n \nSynonyms:\ntallgrass/item.fetch_by_id\ntallgrass/item fetch_by_id","url":"tallgrass/item.html#fetch_by_id"},{"doc":"tallgrass/item","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Item, Error)\n Fetches an item given the item name.\n\n # Example\n\n \n let result = item.new() |&gt; item.fetch_by_name(&quot;master-ball&quot;)\n \nSynonyms:\ntallgrass/item.fetch_by_name\ntallgrass/item fetch_by_name","url":"tallgrass/item.html#fetch_by_name"},{"doc":"tallgrass/item","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Item, Error)\n Fetches an item given an item resource.\n\n # Example\n\n \n let client = client.new()\n use res &lt;- result.try(client |&gt; item.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; item.fetch_resource(first)\n \nSynonyms:\ntallgrass/item.fetch_resource\ntallgrass/item fetch_resource","url":"tallgrass/item.html#fetch_resource"},{"doc":"tallgrass/item","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/item.new\ntallgrass/item new","url":"tallgrass/item.html#new"},{"doc":"tallgrass/item","title":"tallgrass/item","content":"","url":"tallgrass/item.html"},{"doc":"tallgrass/item/attribute","title":"ItemAttribute","content":"pub type ItemAttribute {\n  ItemAttribute(\n    id: Int,\n    name: String,\n    descriptions: List(Description),\n    items: List(Resource),\n    names: List(Name),\n  )\n}\n\nItemAttribute(\n  id: Int,\n  name: String,\n  descriptions: List(Description),\n  items: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/item/attribute.ItemAttribute\ntallgrass/item/attribute ItemAttribute","url":"tallgrass/item/attribute.html#ItemAttribute"},{"doc":"tallgrass/item/attribute","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of item attribute resources.\n\n # Example\n\n \n let result = attribute.new() |&gt; attribute.fetch()\n \nSynonyms:\ntallgrass/item/attribute.fetch\ntallgrass/item/attribute fetch","url":"tallgrass/item/attribute.html#fetch"},{"doc":"tallgrass/item/attribute","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ItemAttribute, Error)\n Fetches an item attribute given the item attribute ID.\n\n # Example\n\n \n let result = attribute.new() |&gt; attribute.fetch_by_id(1)\n \nSynonyms:\ntallgrass/item/attribute.fetch_by_id\ntallgrass/item/attribute fetch_by_id","url":"tallgrass/item/attribute.html#fetch_by_id"},{"doc":"tallgrass/item/attribute","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(ItemAttribute, Error)\n Fetches an item attribute given the item attribute name.\n\n # Example\n\n \n let result = attribute.new() |&gt; attribute.fetch_by_name(&quot;countable&quot;)\n \nSynonyms:\ntallgrass/item/attribute.fetch_by_name\ntallgrass/item/attribute fetch_by_name","url":"tallgrass/item/attribute.html#fetch_by_name"},{"doc":"tallgrass/item/attribute","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ItemAttribute, Error)\n Fetches an item attribute given an item attribute resource.\n\n # Example\n\n \n let client = attribute.new()\n use res &lt;- result.try(client |&gt; attribute.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; attribute.fetch_resource(first)\n \nSynonyms:\ntallgrass/item/attribute.fetch_resource\ntallgrass/item/attribute fetch_resource","url":"tallgrass/item/attribute.html#fetch_resource"},{"doc":"tallgrass/item/attribute","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/item/attribute.new\ntallgrass/item/attribute new","url":"tallgrass/item/attribute.html#new"},{"doc":"tallgrass/item/attribute","title":"tallgrass/item/attribute","content":"","url":"tallgrass/item/attribute.html"},{"doc":"tallgrass/item/category","title":"ItemCategory","content":"pub type ItemCategory {\n  ItemCategory(\n    id: Int,\n    name: String,\n    items: List(Resource),\n    names: List(Name),\n    pocket: Resource,\n  )\n}\n\nItemCategory(\n  id: Int,\n  name: String,\n  items: List(Resource),\n  names: List(Name),\n  pocket: Resource,\n)\n\n\nSynonyms:\ntallgrass/item/category.ItemCategory\ntallgrass/item/category ItemCategory","url":"tallgrass/item/category.html#ItemCategory"},{"doc":"tallgrass/item/category","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of item category resources.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch()\n \nSynonyms:\ntallgrass/item/category.fetch\ntallgrass/item/category fetch","url":"tallgrass/item/category.html#fetch"},{"doc":"tallgrass/item/category","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ItemCategory, Error)\n Fetches an item category given the item category ID.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch_by_id(1)\n \nSynonyms:\ntallgrass/item/category.fetch_by_id\ntallgrass/item/category fetch_by_id","url":"tallgrass/item/category.html#fetch_by_id"},{"doc":"tallgrass/item/category","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(ItemCategory, Error)\n Fetches an item category given the item category name.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch_by_name(&quot;stat-boosts&quot;)\n \nSynonyms:\ntallgrass/item/category.fetch_by_name\ntallgrass/item/category fetch_by_name","url":"tallgrass/item/category.html#fetch_by_name"},{"doc":"tallgrass/item/category","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ItemCategory, Error)\n Fetches an item category given an item category resource.\n\n # Example\n\n \n let client = category.new()\n use res &lt;- result.try(client |&gt; category.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; category.fetch_resource(first)\n \nSynonyms:\ntallgrass/item/category.fetch_resource\ntallgrass/item/category fetch_resource","url":"tallgrass/item/category.html#fetch_resource"},{"doc":"tallgrass/item/category","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/item/category.new\ntallgrass/item/category new","url":"tallgrass/item/category.html#new"},{"doc":"tallgrass/item/category","title":"tallgrass/item/category","content":"","url":"tallgrass/item/category.html"},{"doc":"tallgrass/item/fling_effect","title":"ItemFlingEffect","content":"pub type ItemFlingEffect {\n  ItemFlingEffect(\n    id: Int,\n    name: String,\n    effect_entries: List(Effect),\n    items: List(Resource),\n  )\n}\n\nItemFlingEffect(\n  id: Int,\n  name: String,\n  effect_entries: List(Effect),\n  items: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/item/fling_effect.ItemFlingEffect\ntallgrass/item/fling_effect ItemFlingEffect","url":"tallgrass/item/fling_effect.html#ItemFlingEffect"},{"doc":"tallgrass/item/fling_effect","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of item fling effect resources.\n\n # Example\n\n \n let result = fling_effect.new() |&gt; fling_effect.fetch()\n \nSynonyms:\ntallgrass/item/fling_effect.fetch\ntallgrass/item/fling_effect fetch","url":"tallgrass/item/fling_effect.html#fetch"},{"doc":"tallgrass/item/fling_effect","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ItemFlingEffect, Error)\n Fetches an item fling effect given the item fling effect ID.\n\n # Example\n\n \n let result = fling_effect.new() |&gt; fling_effect.fetch_by_id(1)\n \nSynonyms:\ntallgrass/item/fling_effect.fetch_by_id\ntallgrass/item/fling_effect fetch_by_id","url":"tallgrass/item/fling_effect.html#fetch_by_id"},{"doc":"tallgrass/item/fling_effect","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(ItemFlingEffect, Error)\n Fetches an item fling effect given the item fling effect name.\n\n # Example\n\n \n let result = fling_effect.new() |&gt; fling_effect.fetch_by_name(&quot;badly-poison&quot;)\n \nSynonyms:\ntallgrass/item/fling_effect.fetch_by_name\ntallgrass/item/fling_effect fetch_by_name","url":"tallgrass/item/fling_effect.html#fetch_by_name"},{"doc":"tallgrass/item/fling_effect","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ItemFlingEffect, Error)\n Fetches an item fling effect given an item fling effect resource.\n\n # Example\n\n \n let client = fling_effect.new()\n use res &lt;- result.try(client |&gt; fling_effect.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; fling_effect.fetch_resource(first)\n \nSynonyms:\ntallgrass/item/fling_effect.fetch_resource\ntallgrass/item/fling_effect fetch_resource","url":"tallgrass/item/fling_effect.html#fetch_resource"},{"doc":"tallgrass/item/fling_effect","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/item/fling_effect.new\ntallgrass/item/fling_effect new","url":"tallgrass/item/fling_effect.html#new"},{"doc":"tallgrass/item/fling_effect","title":"tallgrass/item/fling_effect","content":"","url":"tallgrass/item/fling_effect.html"},{"doc":"tallgrass/item/pocket","title":"ItemPocket","content":"pub type ItemPocket {\n  ItemPocket(\n    id: Int,\n    name: String,\n    categories: List(Resource),\n    names: List(Name),\n  )\n}\n\nItemPocket(\n  id: Int,\n  name: String,\n  categories: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/item/pocket.ItemPocket\ntallgrass/item/pocket ItemPocket","url":"tallgrass/item/pocket.html#ItemPocket"},{"doc":"tallgrass/item/pocket","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of item pocket resources.\n\n # Example\n\n \n let result = pocket.new() |&gt; pocket.fetch()\n \nSynonyms:\ntallgrass/item/pocket.fetch\ntallgrass/item/pocket fetch","url":"tallgrass/item/pocket.html#fetch"},{"doc":"tallgrass/item/pocket","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(ItemPocket, Error)\n Fetches an item pocket given the item pocket ID.\n\n # Example\n\n \n let result = pocket.new() |&gt; pocket.fetch_by_id(1)\n \nSynonyms:\ntallgrass/item/pocket.fetch_by_id\ntallgrass/item/pocket fetch_by_id","url":"tallgrass/item/pocket.html#fetch_by_id"},{"doc":"tallgrass/item/pocket","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(ItemPocket, Error)\n Fetches an item pocket given the item pocket name.\n\n # Example\n\n \n let result = pocket.new() |&gt; pocket.fetch_by_name(&quot;misc&quot;)\n \nSynonyms:\ntallgrass/item/pocket.fetch_by_name\ntallgrass/item/pocket fetch_by_name","url":"tallgrass/item/pocket.html#fetch_by_name"},{"doc":"tallgrass/item/pocket","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(ItemPocket, Error)\n Fetches an item pocket given an item pocket resource.\n\n # Example\n\n \n let client = pocket.new()\n use res &lt;- result.try(client |&gt; pocket.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pocket.fetch_resource(first)\n \nSynonyms:\ntallgrass/item/pocket.fetch_resource\ntallgrass/item/pocket fetch_resource","url":"tallgrass/item/pocket.html#fetch_resource"},{"doc":"tallgrass/item/pocket","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/item/pocket.new\ntallgrass/item/pocket new","url":"tallgrass/item/pocket.html#new"},{"doc":"tallgrass/item/pocket","title":"tallgrass/item/pocket","content":"","url":"tallgrass/item/pocket.html"},{"doc":"tallgrass/location","title":"Location","content":"pub type Location {\n  Location(\n    id: Int,\n    name: String,\n    region: Resource,\n    names: List(Name),\n    game_indices: List(GenerationGameIndex),\n    areas: List(Resource),\n  )\n}\n\nLocation(\n  id: Int,\n  name: String,\n  region: Resource,\n  names: List(Name),\n  game_indices: List(GenerationGameIndex),\n  areas: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/location.Location\ntallgrass/location Location","url":"tallgrass/location.html#Location"},{"doc":"tallgrass/location","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of location resources.\n\n # Example\n\n \n let result = location.new() |&gt; location.fetch()\n \nSynonyms:\ntallgrass/location.fetch\ntallgrass/location fetch","url":"tallgrass/location.html#fetch"},{"doc":"tallgrass/location","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Location, Error)\n Fetches a location given the location ID.\n\n # Example\n\n \n let result = location.new() |&gt; location.fetch_by_id(1)\n \nSynonyms:\ntallgrass/location.fetch_by_id\ntallgrass/location fetch_by_id","url":"tallgrass/location.html#fetch_by_id"},{"doc":"tallgrass/location","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Location, Error)\n Fetches a location given the location name.\n\n # Example\n\n \n let result = location.new() |&gt; location.fetch_by_name(&quot;canalave-city&quot;)\n \nSynonyms:\ntallgrass/location.fetch_by_name\ntallgrass/location fetch_by_name","url":"tallgrass/location.html#fetch_by_name"},{"doc":"tallgrass/location","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Location, Error)\n Fetches a location given a location resource.\n\n # Example\n\n \n let client = location.new()\n use res &lt;- result.try(client |&gt; location.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; location.fetch_resource(first)\n \nSynonyms:\ntallgrass/location.fetch_resource\ntallgrass/location fetch_resource","url":"tallgrass/location.html#fetch_resource"},{"doc":"tallgrass/location","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/location.new\ntallgrass/location new","url":"tallgrass/location.html#new"},{"doc":"tallgrass/location","title":"tallgrass/location","content":"","url":"tallgrass/location.html"},{"doc":"tallgrass/location/area","title":"LocationArea","content":"pub type LocationArea {\n  LocationArea(\n    id: Int,\n    name: String,\n    game_index: Int,\n    location: Resource,\n    names: List(Name),\n  )\n}\n\nLocationArea(\n  id: Int,\n  name: String,\n  game_index: Int,\n  location: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/location/area.LocationArea\ntallgrass/location/area LocationArea","url":"tallgrass/location/area.html#LocationArea"},{"doc":"tallgrass/location/area","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of location area resources.\n\n # Example\n\n \n let result = area.new() |&gt; area.fetch()\n \nSynonyms:\ntallgrass/location/area.fetch\ntallgrass/location/area fetch","url":"tallgrass/location/area.html#fetch"},{"doc":"tallgrass/location/area","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(LocationArea, Error)\n Fetches a location area given the location area ID.\n\n # Example\n\n \n let result = area.new() |&gt; area.fetch_by_id(1)\n \nSynonyms:\ntallgrass/location/area.fetch_by_id\ntallgrass/location/area fetch_by_id","url":"tallgrass/location/area.html#fetch_by_id"},{"doc":"tallgrass/location/area","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(LocationArea, Error)\n Fetches a location area given the location area name.\n\n # Example\n\n \n let result = area.new() |&gt; area.fetch_by_name(&quot;canalave-city-area&quot;)\n \nSynonyms:\ntallgrass/location/area.fetch_by_name\ntallgrass/location/area fetch_by_name","url":"tallgrass/location/area.html#fetch_by_name"},{"doc":"tallgrass/location/area","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(LocationArea, Error)\n Fetches a location area given a location area resource.\n\n # Example\n\n \n let client = area.new()\n use res &lt;- result.try(client |&gt; area.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; area.fetch_resource(first)\n \nSynonyms:\ntallgrass/location/area.fetch_resource\ntallgrass/location/area fetch_resource","url":"tallgrass/location/area.html#fetch_resource"},{"doc":"tallgrass/location/area","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/location/area.new\ntallgrass/location/area new","url":"tallgrass/location/area.html#new"},{"doc":"tallgrass/location/area","title":"tallgrass/location/area","content":"","url":"tallgrass/location/area.html"},{"doc":"tallgrass/location/pal_park_area","title":"PalParkArea","content":"pub type PalParkArea {\n  PalParkArea(id: Int, name: String, names: List(Name))\n}\n\nPalParkArea(id: Int, name: String, names: List(Name))\n\n\nSynonyms:\ntallgrass/location/pal_park_area.PalParkArea\ntallgrass/location/pal_park_area PalParkArea","url":"tallgrass/location/pal_park_area.html#PalParkArea"},{"doc":"tallgrass/location/pal_park_area","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pal park area resources.\n\n # Example\n\n \n let result = pal_park_area.new() |&gt; pal_park_area.fetch()\n \nSynonyms:\ntallgrass/location/pal_park_area.fetch\ntallgrass/location/pal_park_area fetch","url":"tallgrass/location/pal_park_area.html#fetch"},{"doc":"tallgrass/location/pal_park_area","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PalParkArea, Error)\n Fetches a pal park area given the pal park area ID.\n\n # Example\n\n \n let result = pal_park_area.new() |&gt; pal_park_area.fetch_by_id(1)\n \nSynonyms:\ntallgrass/location/pal_park_area.fetch_by_id\ntallgrass/location/pal_park_area fetch_by_id","url":"tallgrass/location/pal_park_area.html#fetch_by_id"},{"doc":"tallgrass/location/pal_park_area","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PalParkArea, Error)\n Fetches a pal park area given the pal park area name.\n\n # Example\n\n \n let result = pal_park_area.new() |&gt; pal_park_area.fetch_by_name(&quot;forest&quot;)\n \nSynonyms:\ntallgrass/location/pal_park_area.fetch_by_name\ntallgrass/location/pal_park_area fetch_by_name","url":"tallgrass/location/pal_park_area.html#fetch_by_name"},{"doc":"tallgrass/location/pal_park_area","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PalParkArea, Error)\n Fetches a pal park area given a pal park area resource.\n\n # Example\n\n \n let client = pal_park_area.new()\n use res &lt;- result.try(client |&gt; pal_park_area.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pal_park_area.fetch_resource(first)\n \nSynonyms:\ntallgrass/location/pal_park_area.fetch_resource\ntallgrass/location/pal_park_area fetch_resource","url":"tallgrass/location/pal_park_area.html#fetch_resource"},{"doc":"tallgrass/location/pal_park_area","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/location/pal_park_area.new\ntallgrass/location/pal_park_area new","url":"tallgrass/location/pal_park_area.html#new"},{"doc":"tallgrass/location/pal_park_area","title":"tallgrass/location/pal_park_area","content":"","url":"tallgrass/location/pal_park_area.html"},{"doc":"tallgrass/location/region","title":"Region","content":"pub type Region {\n  Region(\n    id: Int,\n    name: String,\n    locations: List(Resource),\n    main_generation: Resource,\n    names: List(Name),\n    pokedexes: List(Resource),\n    version_groups: List(Resource),\n  )\n}\n\nRegion(\n  id: Int,\n  name: String,\n  locations: List(Resource),\n  main_generation: Resource,\n  names: List(Name),\n  pokedexes: List(Resource),\n  version_groups: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/location/region.Region\ntallgrass/location/region Region","url":"tallgrass/location/region.html#Region"},{"doc":"tallgrass/location/region","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of region resources.\n\n # Example\n\n \n let result = region.new() |&gt; region.fetch()\n \nSynonyms:\ntallgrass/location/region.fetch\ntallgrass/location/region fetch","url":"tallgrass/location/region.html#fetch"},{"doc":"tallgrass/location/region","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Region, Error)\n Fetches a region given the region ID.\n\n # Example\n\n \n let result = region.new() |&gt; region.fetch_by_id(1)\n \nSynonyms:\ntallgrass/location/region.fetch_by_id\ntallgrass/location/region fetch_by_id","url":"tallgrass/location/region.html#fetch_by_id"},{"doc":"tallgrass/location/region","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Region, Error)\n Fetches a region given the region name.\n\n # Example\n\n \n let result = region.new() |&gt; region.fetch_by_name(&quot;kanto&quot;)\n \nSynonyms:\ntallgrass/location/region.fetch_by_name\ntallgrass/location/region fetch_by_name","url":"tallgrass/location/region.html#fetch_by_name"},{"doc":"tallgrass/location/region","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Region, Error)\n Fetches a region given a region resource.\n\n # Example\n\n \n let client = region.new()\n use res &lt;- result.try(client |&gt; region.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; region.fetch_resource(first)\n \nSynonyms:\ntallgrass/location/region.fetch_resource\ntallgrass/location/region fetch_resource","url":"tallgrass/location/region.html#fetch_resource"},{"doc":"tallgrass/location/region","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/location/region.new\ntallgrass/location/region new","url":"tallgrass/location/region.html#new"},{"doc":"tallgrass/location/region","title":"tallgrass/location/region","content":"","url":"tallgrass/location/region.html"},{"doc":"tallgrass/machine","title":"Machine","content":"pub type Machine {\n  Machine(\n    id: Int,\n    item: Resource,\n    move: Resource,\n    version_group: Resource,\n  )\n}\n\nMachine(\n  id: Int,\n  item: Resource,\n  move: Resource,\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/machine.Machine\ntallgrass/machine Machine","url":"tallgrass/machine.html#Machine"},{"doc":"tallgrass/machine","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of machine resources.\n\n # Example\n\n \n let result = machine.new() |&gt; machine.fetch()\n \nSynonyms:\ntallgrass/machine.fetch\ntallgrass/machine fetch","url":"tallgrass/machine.html#fetch"},{"doc":"tallgrass/machine","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Machine, Error)\n Fetches a machine given the machine ID.\n\n # Example\n\n \n let result = machine.new() |&gt; machine.fetch_by_id(1)\n \nSynonyms:\ntallgrass/machine.fetch_by_id\ntallgrass/machine fetch_by_id","url":"tallgrass/machine.html#fetch_by_id"},{"doc":"tallgrass/machine","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Machine, Error)\n Fetches a machine given a machine resource.\n\n # Example\n\n \n let client = machine.new()\n use res &lt;- result.try(client |&gt; machine.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; machine.fetch_resource(first)\n \nSynonyms:\ntallgrass/machine.fetch_resource\ntallgrass/machine fetch_resource","url":"tallgrass/machine.html#fetch_resource"},{"doc":"tallgrass/machine","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/machine.new\ntallgrass/machine new","url":"tallgrass/machine.html#new"},{"doc":"tallgrass/machine","title":"tallgrass/machine","content":"","url":"tallgrass/machine.html"},{"doc":"tallgrass/move","title":"Move","content":"pub type Move {\n  Move(\n    id: Int,\n    name: String,\n    accuracy: Int,\n    effect_chance: Option(Int),\n    pp: Int,\n    priority: Int,\n    power: Int,\n    contest_type: Resource,\n    contest_effect: Resource,\n    damage_class: Resource,\n    effect_entries: List(VerboseEffect),\n    generation: Resource,\n    names: List(Name),\n    super_contest_effect: Resource,\n    target: Resource,\n    pokemon_type: Resource,\n    learned_by_pokemon: List(Resource),\n    flavor_text_entries: List(FlavorTextVersionGroup),\n  )\n}\n\nMove(\n  id: Int,\n  name: String,\n  accuracy: Int,\n  effect_chance: Option(Int),\n  pp: Int,\n  priority: Int,\n  power: Int,\n  contest_type: Resource,\n  contest_effect: Resource,\n  damage_class: Resource,\n  effect_entries: List(VerboseEffect),\n  generation: Resource,\n  names: List(Name),\n  super_contest_effect: Resource,\n  target: Resource,\n  pokemon_type: Resource,\n  learned_by_pokemon: List(Resource),\n  flavor_text_entries: List(FlavorTextVersionGroup),\n)\n\n\nSynonyms:\ntallgrass/move.Move\ntallgrass/move Move","url":"tallgrass/move.html#Move"},{"doc":"tallgrass/move","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move resources.\n\n # Example\n\n \n let result = move.new() |&gt; move.fetch()\n \nSynonyms:\ntallgrass/move.fetch\ntallgrass/move fetch","url":"tallgrass/move.html#fetch"},{"doc":"tallgrass/move","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Move, Error)\n Fetches a move given the move ID.\n\n # Example\n\n \n let result = move.new() |&gt; move.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move.fetch_by_id\ntallgrass/move fetch_by_id","url":"tallgrass/move.html#fetch_by_id"},{"doc":"tallgrass/move","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Move, Error)\n Fetches a move given the move name.\n\n # Example\n\n \n let result = move.new() |&gt; move.fetch_by_name(&quot;pound&quot;)\n \nSynonyms:\ntallgrass/move.fetch_by_name\ntallgrass/move fetch_by_name","url":"tallgrass/move.html#fetch_by_name"},{"doc":"tallgrass/move","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Move, Error)\n Fetches a move given a move resource.\n\n # Example\n\n \n let client = move.new()\n use res &lt;- result.try(client |&gt; move.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; move.fetch_resource(first)\n \nSynonyms:\ntallgrass/move.fetch_resource\ntallgrass/move fetch_resource","url":"tallgrass/move.html#fetch_resource"},{"doc":"tallgrass/move","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move.new\ntallgrass/move new","url":"tallgrass/move.html#new"},{"doc":"tallgrass/move","title":"tallgrass/move","content":"","url":"tallgrass/move.html"},{"doc":"tallgrass/move/ailment","title":"MoveAilment","content":"pub type MoveAilment {\n  MoveAilment(\n    id: Int,\n    name: String,\n    moves: List(Resource),\n    names: List(Name),\n  )\n}\n\nMoveAilment(\n  id: Int,\n  name: String,\n  moves: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/move/ailment.MoveAilment\ntallgrass/move/ailment MoveAilment","url":"tallgrass/move/ailment.html#MoveAilment"},{"doc":"tallgrass/move/ailment","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move ailment resources.\n\n # Example\n\n \n let result = ailment.new() |&gt; ailment.fetch()\n \nSynonyms:\ntallgrass/move/ailment.fetch\ntallgrass/move/ailment fetch","url":"tallgrass/move/ailment.html#fetch"},{"doc":"tallgrass/move/ailment","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveAilment, Error)\n Fetches a move ailment given the move ailment ID.\n\n # Example\n\n \n let result = ailment.new() |&gt; ailment.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/ailment.fetch_by_id\ntallgrass/move/ailment fetch_by_id","url":"tallgrass/move/ailment.html#fetch_by_id"},{"doc":"tallgrass/move/ailment","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveAilment, Error)\n Fetches a move ailment given the move ailment name.\n\n # Example\n\n \n let result = ailment.new() |&gt; ailment.fetch_by_name(&quot;paralysis&quot;)\n \nSynonyms:\ntallgrass/move/ailment.fetch_by_name\ntallgrass/move/ailment fetch_by_name","url":"tallgrass/move/ailment.html#fetch_by_name"},{"doc":"tallgrass/move/ailment","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveAilment, Error)\n Fetches a move ailment given a move ailment resource.\n\n # Example\n\n \n let client = ailment.new()\n use res &lt;- result.try(client |&gt; ailment.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; ailment.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/ailment.fetch_resource\ntallgrass/move/ailment fetch_resource","url":"tallgrass/move/ailment.html#fetch_resource"},{"doc":"tallgrass/move/ailment","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/ailment.new\ntallgrass/move/ailment new","url":"tallgrass/move/ailment.html#new"},{"doc":"tallgrass/move/ailment","title":"tallgrass/move/ailment","content":"","url":"tallgrass/move/ailment.html"},{"doc":"tallgrass/move/battle_style","title":"MoveBattleStyle","content":"pub type MoveBattleStyle {\n  MoveBattleStyle(id: Int, name: String, names: List(Name))\n}\n\nMoveBattleStyle(id: Int, name: String, names: List(Name))\n\n\nSynonyms:\ntallgrass/move/battle_style.MoveBattleStyle\ntallgrass/move/battle_style MoveBattleStyle","url":"tallgrass/move/battle_style.html#MoveBattleStyle"},{"doc":"tallgrass/move/battle_style","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move battle style resources.\n\n # Example\n\n \n let result = battle_style.new() |&gt; battle_style.fetch()\n \nSynonyms:\ntallgrass/move/battle_style.fetch\ntallgrass/move/battle_style fetch","url":"tallgrass/move/battle_style.html#fetch"},{"doc":"tallgrass/move/battle_style","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveBattleStyle, Error)\n Fetches a move battle style given the move battle style ID.\n\n # Example\n\n \n let result = battle_style.new() |&gt; battle_style.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/battle_style.fetch_by_id\ntallgrass/move/battle_style fetch_by_id","url":"tallgrass/move/battle_style.html#fetch_by_id"},{"doc":"tallgrass/move/battle_style","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveBattleStyle, Error)\n Fetches a move battle style given the move battle style name.\n\n # Example\n\n \n let result = battle_style.new() |&gt; battle_style.fetch_by_name(&quot;attack&quot;)\n \nSynonyms:\ntallgrass/move/battle_style.fetch_by_name\ntallgrass/move/battle_style fetch_by_name","url":"tallgrass/move/battle_style.html#fetch_by_name"},{"doc":"tallgrass/move/battle_style","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveBattleStyle, Error)\n Fetches a move battle style given a move battle style resource.\n\n # Example\n\n \n let client = battle_style.new()\n use res &lt;- result.try(client |&gt; battle_style.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; battle_style.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/battle_style.fetch_resource\ntallgrass/move/battle_style fetch_resource","url":"tallgrass/move/battle_style.html#fetch_resource"},{"doc":"tallgrass/move/battle_style","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/battle_style.new\ntallgrass/move/battle_style new","url":"tallgrass/move/battle_style.html#new"},{"doc":"tallgrass/move/battle_style","title":"tallgrass/move/battle_style","content":"","url":"tallgrass/move/battle_style.html"},{"doc":"tallgrass/move/category","title":"MoveCategory","content":"pub type MoveCategory {\n  MoveCategory(\n    id: Int,\n    name: String,\n    descriptions: List(Description),\n    moves: List(Resource),\n  )\n}\n\nMoveCategory(\n  id: Int,\n  name: String,\n  descriptions: List(Description),\n  moves: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/move/category.MoveCategory\ntallgrass/move/category MoveCategory","url":"tallgrass/move/category.html#MoveCategory"},{"doc":"tallgrass/move/category","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move category resources.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch()\n \nSynonyms:\ntallgrass/move/category.fetch\ntallgrass/move/category fetch","url":"tallgrass/move/category.html#fetch"},{"doc":"tallgrass/move/category","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveCategory, Error)\n Fetches a move category given the move category ID.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/category.fetch_by_id\ntallgrass/move/category fetch_by_id","url":"tallgrass/move/category.html#fetch_by_id"},{"doc":"tallgrass/move/category","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveCategory, Error)\n Fetches a move category given the move category name.\n\n # Example\n\n \n let result = category.new() |&gt; category.fetch_by_name(&quot;ailment&quot;)\n \nSynonyms:\ntallgrass/move/category.fetch_by_name\ntallgrass/move/category fetch_by_name","url":"tallgrass/move/category.html#fetch_by_name"},{"doc":"tallgrass/move/category","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveCategory, Error)\n Fetches a move category given a move category resource.\n\n # Example\n\n \n let client = category.new()\n use res &lt;- result.try(client |&gt; category.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; category.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/category.fetch_resource\ntallgrass/move/category fetch_resource","url":"tallgrass/move/category.html#fetch_resource"},{"doc":"tallgrass/move/category","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/category.new\ntallgrass/move/category new","url":"tallgrass/move/category.html#new"},{"doc":"tallgrass/move/category","title":"tallgrass/move/category","content":"","url":"tallgrass/move/category.html"},{"doc":"tallgrass/move/damage_class","title":"MoveDamageClass","content":"pub type MoveDamageClass {\n  MoveDamageClass(\n    id: Int,\n    name: String,\n    descriptions: List(Description),\n    moves: List(Resource),\n    names: List(Name),\n  )\n}\n\nMoveDamageClass(\n  id: Int,\n  name: String,\n  descriptions: List(Description),\n  moves: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/move/damage_class.MoveDamageClass\ntallgrass/move/damage_class MoveDamageClass","url":"tallgrass/move/damage_class.html#MoveDamageClass"},{"doc":"tallgrass/move/damage_class","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move damage class resources.\n\n # Example\n\n \n let result = damage_class.new() |&gt; damage_class.fetch()\n \nSynonyms:\ntallgrass/move/damage_class.fetch\ntallgrass/move/damage_class fetch","url":"tallgrass/move/damage_class.html#fetch"},{"doc":"tallgrass/move/damage_class","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveDamageClass, Error)\n Fetches a move damage class given the move damage class ID.\n\n # Example\n\n \n let result = damage_class.new() |&gt; damage_class.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/damage_class.fetch_by_id\ntallgrass/move/damage_class fetch_by_id","url":"tallgrass/move/damage_class.html#fetch_by_id"},{"doc":"tallgrass/move/damage_class","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveDamageClass, Error)\n Fetches a move damage class given the move damage class name.\n\n # Example\n\n \n let result = damage_class.new() |&gt; damage_class.fetch_by_name(&quot;status&quot;)\n \nSynonyms:\ntallgrass/move/damage_class.fetch_by_name\ntallgrass/move/damage_class fetch_by_name","url":"tallgrass/move/damage_class.html#fetch_by_name"},{"doc":"tallgrass/move/damage_class","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveDamageClass, Error)\n Fetches a move damage class given a move damage class resource.\n\n # Example\n\n \n let client = damage_class.new()\n use res &lt;- result.try(client |&gt; damage_class.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; damage_class.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/damage_class.fetch_resource\ntallgrass/move/damage_class fetch_resource","url":"tallgrass/move/damage_class.html#fetch_resource"},{"doc":"tallgrass/move/damage_class","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/damage_class.new\ntallgrass/move/damage_class new","url":"tallgrass/move/damage_class.html#new"},{"doc":"tallgrass/move/damage_class","title":"tallgrass/move/damage_class","content":"","url":"tallgrass/move/damage_class.html"},{"doc":"tallgrass/move/learn_method","title":"MoveLearnMethod","content":"pub type MoveLearnMethod {\n  MoveLearnMethod(\n    id: Int,\n    name: String,\n    descriptions: List(Description),\n    names: List(Name),\n    version_groups: List(Resource),\n  )\n}\n\nMoveLearnMethod(\n  id: Int,\n  name: String,\n  descriptions: List(Description),\n  names: List(Name),\n  version_groups: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/move/learn_method.MoveLearnMethod\ntallgrass/move/learn_method MoveLearnMethod","url":"tallgrass/move/learn_method.html#MoveLearnMethod"},{"doc":"tallgrass/move/learn_method","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move learn method resources.\n\n # Example\n\n \n let result = learn_method.new() |&gt; learn_method.fetch()\n \nSynonyms:\ntallgrass/move/learn_method.fetch\ntallgrass/move/learn_method fetch","url":"tallgrass/move/learn_method.html#fetch"},{"doc":"tallgrass/move/learn_method","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveLearnMethod, Error)\n Fetches a move learn method given the move learn method ID.\n\n # Example\n\n \n let result = learn_method.new() |&gt; learn_method.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/learn_method.fetch_by_id\ntallgrass/move/learn_method fetch_by_id","url":"tallgrass/move/learn_method.html#fetch_by_id"},{"doc":"tallgrass/move/learn_method","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveLearnMethod, Error)\n Fetches a move learn method given the move learn method name.\n\n # Example\n\n \n let result = learn_method.new() |&gt; learn_method.fetch_by_name(&quot;level-up&quot;)\n \nSynonyms:\ntallgrass/move/learn_method.fetch_by_name\ntallgrass/move/learn_method fetch_by_name","url":"tallgrass/move/learn_method.html#fetch_by_name"},{"doc":"tallgrass/move/learn_method","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveLearnMethod, Error)\n Fetches a move learn method given a move learn method resource.\n\n # Example\n\n \n let client = learn_method.new()\n use res &lt;- result.try(client |&gt; learn_method.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; learn_method.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/learn_method.fetch_resource\ntallgrass/move/learn_method fetch_resource","url":"tallgrass/move/learn_method.html#fetch_resource"},{"doc":"tallgrass/move/learn_method","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/learn_method.new\ntallgrass/move/learn_method new","url":"tallgrass/move/learn_method.html#new"},{"doc":"tallgrass/move/learn_method","title":"tallgrass/move/learn_method","content":"","url":"tallgrass/move/learn_method.html"},{"doc":"tallgrass/move/target","title":"MoveTarget","content":"pub type MoveTarget {\n  MoveTarget(\n    id: Int,\n    name: String,\n    descriptions: List(Description),\n    moves: List(Resource),\n    names: List(Name),\n  )\n}\n\nMoveTarget(\n  id: Int,\n  name: String,\n  descriptions: List(Description),\n  moves: List(Resource),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/move/target.MoveTarget\ntallgrass/move/target MoveTarget","url":"tallgrass/move/target.html#MoveTarget"},{"doc":"tallgrass/move/target","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of move target resources.\n\n # Example\n\n \n let result = target.new() |&gt; target.fetch()\n \nSynonyms:\ntallgrass/move/target.fetch\ntallgrass/move/target fetch","url":"tallgrass/move/target.html#fetch"},{"doc":"tallgrass/move/target","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(MoveTarget, Error)\n Fetches a move target given the move target ID.\n\n # Example\n\n \n let result = target.new() |&gt; target.fetch_by_id(1)\n \nSynonyms:\ntallgrass/move/target.fetch_by_id\ntallgrass/move/target fetch_by_id","url":"tallgrass/move/target.html#fetch_by_id"},{"doc":"tallgrass/move/target","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(MoveTarget, Error)\n Fetches a move target given the move target name.\n\n # Example\n\n \n let result = target.new() |&gt; target.fetch_by_name(&quot;specific-move&quot;)\n \nSynonyms:\ntallgrass/move/target.fetch_by_name\ntallgrass/move/target fetch_by_name","url":"tallgrass/move/target.html#fetch_by_name"},{"doc":"tallgrass/move/target","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(MoveTarget, Error)\n Fetches a move target given a move target resource.\n\n # Example\n\n \n let client = target.new()\n use res &lt;- result.try(client |&gt; target.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; target.fetch_resource(first)\n \nSynonyms:\ntallgrass/move/target.fetch_resource\ntallgrass/move/target fetch_resource","url":"tallgrass/move/target.html#fetch_resource"},{"doc":"tallgrass/move/target","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/move/target.new\ntallgrass/move/target new","url":"tallgrass/move/target.html#new"},{"doc":"tallgrass/move/target","title":"tallgrass/move/target","content":"","url":"tallgrass/move/target.html"},{"doc":"tallgrass/pokemon","title":"Pokemon","content":"pub type Pokemon {\n  Pokemon(\n    id: Int,\n    name: String,\n    base_experience: Int,\n    cries: PokemonCries,\n    height: Int,\n    is_default: Bool,\n    order: Int,\n    weight: Int,\n    abilities: List(PokemonAbility),\n    forms: List(Resource),\n    game_indices: List(VersionGameIndex),\n    held_items: List(PokemonHeldItem),\n    location_area_encounters: String,\n    moves: List(PokemonMove),\n    species: Resource,\n    stats: List(PokemonStat),\n    types: List(PokemonType),\n  )\n}\n\nPokemon(\n  id: Int,\n  name: String,\n  base_experience: Int,\n  cries: PokemonCries,\n  height: Int,\n  is_default: Bool,\n  order: Int,\n  weight: Int,\n  abilities: List(PokemonAbility),\n  forms: List(Resource),\n  game_indices: List(VersionGameIndex),\n  held_items: List(PokemonHeldItem),\n  location_area_encounters: String,\n  moves: List(PokemonMove),\n  species: Resource,\n  stats: List(PokemonStat),\n  types: List(PokemonType),\n)\n\n\nSynonyms:\ntallgrass/pokemon.Pokemon\ntallgrass/pokemon Pokemon","url":"tallgrass/pokemon.html#Pokemon"},{"doc":"tallgrass/pokemon","title":"PokemonAbility","content":"pub type PokemonAbility {\n  PokemonAbility(ability: Resource, is_hidden: Bool, slot: Int)\n}\n\nPokemonAbility(ability: Resource, is_hidden: Bool, slot: Int)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonAbility\ntallgrass/pokemon PokemonAbility","url":"tallgrass/pokemon.html#PokemonAbility"},{"doc":"tallgrass/pokemon","title":"PokemonCries","content":"pub type PokemonCries {\n  PokemonCries(latest: String, legacy: String)\n}\n\nPokemonCries(latest: String, legacy: String)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonCries\ntallgrass/pokemon PokemonCries","url":"tallgrass/pokemon.html#PokemonCries"},{"doc":"tallgrass/pokemon","title":"PokemonHeldItem","content":"pub type PokemonHeldItem {\n  PokemonHeldItem(\n    item: Resource,\n    version_details: List(PokemonHeldItemVersion),\n  )\n}\n\nPokemonHeldItem(\n  item: Resource,\n  version_details: List(PokemonHeldItemVersion),\n)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonHeldItem\ntallgrass/pokemon PokemonHeldItem","url":"tallgrass/pokemon.html#PokemonHeldItem"},{"doc":"tallgrass/pokemon","title":"PokemonHeldItemVersion","content":"pub type PokemonHeldItemVersion {\n  PokemonHeldItemVersion(rarity: Int, version: Resource)\n}\n\nPokemonHeldItemVersion(rarity: Int, version: Resource)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonHeldItemVersion\ntallgrass/pokemon PokemonHeldItemVersion","url":"tallgrass/pokemon.html#PokemonHeldItemVersion"},{"doc":"tallgrass/pokemon","title":"PokemonMove","content":"pub type PokemonMove {\n  PokemonMove(\n    move: Resource,\n    version_details: List(PokemonMoveVersion),\n  )\n}\n\nPokemonMove(\n  move: Resource,\n  version_details: List(PokemonMoveVersion),\n)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonMove\ntallgrass/pokemon PokemonMove","url":"tallgrass/pokemon.html#PokemonMove"},{"doc":"tallgrass/pokemon","title":"PokemonMoveVersion","content":"pub type PokemonMoveVersion {\n  PokemonMoveVersion(\n    learn_level: Int,\n    learn_method: Resource,\n    version_group: Resource,\n  )\n}\n\nPokemonMoveVersion(\n  learn_level: Int,\n  learn_method: Resource,\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonMoveVersion\ntallgrass/pokemon PokemonMoveVersion","url":"tallgrass/pokemon.html#PokemonMoveVersion"},{"doc":"tallgrass/pokemon","title":"PokemonSprites","content":"pub type PokemonSprites {\n  PokemonSprites(\n    back_default: String,\n    back_female: Option(String),\n    back_shiny: String,\n    back_shiny_female: Option(String),\n    front_default: String,\n    front_female: Option(String),\n    front_shiny: String,\n    front_shiny_female: Option(String),\n  )\n}\n\nPokemonSprites(\n  back_default: String,\n  back_female: Option(String),\n  back_shiny: String,\n  back_shiny_female: Option(String),\n  front_default: String,\n  front_female: Option(String),\n  front_shiny: String,\n  front_shiny_female: Option(String),\n)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonSprites\ntallgrass/pokemon PokemonSprites","url":"tallgrass/pokemon.html#PokemonSprites"},{"doc":"tallgrass/pokemon","title":"PokemonStat","content":"pub type PokemonStat {\n  PokemonStat(stat: Resource, base_stat: Int, effort: Int)\n}\n\nPokemonStat(stat: Resource, base_stat: Int, effort: Int)\n\n\nSynonyms:\ntallgrass/pokemon.PokemonStat\ntallgrass/pokemon PokemonStat","url":"tallgrass/pokemon.html#PokemonStat"},{"doc":"tallgrass/pokemon","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon resources.\n\n # Example\n\n \n let result = pokemon.new() |&gt; pokemon.fetch()\n \nSynonyms:\ntallgrass/pokemon.fetch\ntallgrass/pokemon fetch","url":"tallgrass/pokemon.html#fetch"},{"doc":"tallgrass/pokemon","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Pokemon, Error)\n Fetches a pokemon given the pokemon ID.\n\n # Example\n\n \n let result = pokemon.new() |&gt; pokemon.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon.fetch_by_id\ntallgrass/pokemon fetch_by_id","url":"tallgrass/pokemon.html#fetch_by_id"},{"doc":"tallgrass/pokemon","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Pokemon, Error)\n Fetches a pokemon given the pokemon name.\n\n # Example\n\n \n let result = pokemon.new() |&gt; pokemon.fetch_by_name(&quot;ditto&quot;)\n \nSynonyms:\ntallgrass/pokemon.fetch_by_name\ntallgrass/pokemon fetch_by_name","url":"tallgrass/pokemon.html#fetch_by_name"},{"doc":"tallgrass/pokemon","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Pokemon, Error)\n Fetches a pokemon given a pokemon resource.\n\n # Example\n\n \n let client = pokemon.new()\n use res &lt;- result.try(client |&gt; pokemon.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pokemon.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon.fetch_resource\ntallgrass/pokemon fetch_resource","url":"tallgrass/pokemon.html#fetch_resource"},{"doc":"tallgrass/pokemon","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon.new\ntallgrass/pokemon new","url":"tallgrass/pokemon.html#new"},{"doc":"tallgrass/pokemon","title":"tallgrass/pokemon","content":"","url":"tallgrass/pokemon.html"},{"doc":"tallgrass/pokemon/ability","title":"Ability","content":"pub type Ability {\n  Ability(\n    id: Int,\n    name: String,\n    is_main_series: Bool,\n    generation: Resource,\n    names: List(Name),\n    effect_entries: List(VerboseEffect),\n    flavor_text_entries: List(FlavorTextVersionGroup),\n    pokemon: List(AbilityPokemon),\n  )\n}\n\nAbility(\n  id: Int,\n  name: String,\n  is_main_series: Bool,\n  generation: Resource,\n  names: List(Name),\n  effect_entries: List(VerboseEffect),\n  flavor_text_entries: List(FlavorTextVersionGroup),\n  pokemon: List(AbilityPokemon),\n)\n\n\nSynonyms:\ntallgrass/pokemon/ability.Ability\ntallgrass/pokemon/ability Ability","url":"tallgrass/pokemon/ability.html#Ability"},{"doc":"tallgrass/pokemon/ability","title":"AbilityPokemon","content":"pub type AbilityPokemon {\n  AbilityPokemon(is_hidden: Bool, slot: Int, pokemon: Resource)\n}\n\nAbilityPokemon(is_hidden: Bool, slot: Int, pokemon: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/ability.AbilityPokemon\ntallgrass/pokemon/ability AbilityPokemon","url":"tallgrass/pokemon/ability.html#AbilityPokemon"},{"doc":"tallgrass/pokemon/ability","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon ability resources.\n\n # Example\n\n \n let result = ability.new() |&gt; ability.fetch()\n \nSynonyms:\ntallgrass/pokemon/ability.fetch\ntallgrass/pokemon/ability fetch","url":"tallgrass/pokemon/ability.html#fetch"},{"doc":"tallgrass/pokemon/ability","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Ability, Error)\n Fetches a pokemon ability given the pokemon ability ID.\n\n # Example\n\n \n let result = ability.new() |&gt; ability.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/ability.fetch_by_id\ntallgrass/pokemon/ability fetch_by_id","url":"tallgrass/pokemon/ability.html#fetch_by_id"},{"doc":"tallgrass/pokemon/ability","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Ability, Error)\n Fetches a pokemon ability given the pokemon ability name.\n\n # Example\n\n \n let result = ability.new() |&gt; ability.fetch_by_name(&quot;stench&quot;)\n \nSynonyms:\ntallgrass/pokemon/ability.fetch_by_name\ntallgrass/pokemon/ability fetch_by_name","url":"tallgrass/pokemon/ability.html#fetch_by_name"},{"doc":"tallgrass/pokemon/ability","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Ability, Error)\n Fetches a pokemon ability given a pokemon ability resource.\n\n # Example\n\n \n let client = ability.new()\n use res &lt;- result.try(client |&gt; ability.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; ability.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/ability.fetch_resource\ntallgrass/pokemon/ability fetch_resource","url":"tallgrass/pokemon/ability.html#fetch_resource"},{"doc":"tallgrass/pokemon/ability","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/ability.new\ntallgrass/pokemon/ability new","url":"tallgrass/pokemon/ability.html#new"},{"doc":"tallgrass/pokemon/ability","title":"tallgrass/pokemon/ability","content":"","url":"tallgrass/pokemon/ability.html"},{"doc":"tallgrass/pokemon/characteristic","title":"Characteristic","content":"pub type Characteristic {\n  Characteristic(\n    id: Int,\n    gene_modulo: Int,\n    possible_values: List(Int),\n    highest_stat: Resource,\n    descriptions: List(Description),\n  )\n}\n\nCharacteristic(\n  id: Int,\n  gene_modulo: Int,\n  possible_values: List(Int),\n  highest_stat: Resource,\n  descriptions: List(Description),\n)\n\n\nSynonyms:\ntallgrass/pokemon/characteristic.Characteristic\ntallgrass/pokemon/characteristic Characteristic","url":"tallgrass/pokemon/characteristic.html#Characteristic"},{"doc":"tallgrass/pokemon/characteristic","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon characteristic resources.\n\n # Example\n\n \n let result = characteristic.new() |&gt; characteristic.fetch()\n \nSynonyms:\ntallgrass/pokemon/characteristic.fetch\ntallgrass/pokemon/characteristic fetch","url":"tallgrass/pokemon/characteristic.html#fetch"},{"doc":"tallgrass/pokemon/characteristic","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Characteristic, Error)\n Fetches a pokemon characteristic given the pokemon characteristic ID.\n\n # Example\n\n \n let result = characteristic.new() |&gt; characteristic.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/characteristic.fetch_by_id\ntallgrass/pokemon/characteristic fetch_by_id","url":"tallgrass/pokemon/characteristic.html#fetch_by_id"},{"doc":"tallgrass/pokemon/characteristic","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Characteristic, Error)\n Fetches a pokemon characteristic given a pokemon characteristic resource.\n\n # Example\n\n \n let client = characteristic.new()\n use res &lt;- result.try(client |&gt; characteristic.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; characteristic.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/characteristic.fetch_resource\ntallgrass/pokemon/characteristic fetch_resource","url":"tallgrass/pokemon/characteristic.html#fetch_resource"},{"doc":"tallgrass/pokemon/characteristic","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/characteristic.new\ntallgrass/pokemon/characteristic new","url":"tallgrass/pokemon/characteristic.html#new"},{"doc":"tallgrass/pokemon/characteristic","title":"tallgrass/pokemon/characteristic","content":"","url":"tallgrass/pokemon/characteristic.html"},{"doc":"tallgrass/pokemon/color","title":"PokemonColor","content":"pub type PokemonColor {\n  PokemonColor(\n    id: Int,\n    name: String,\n    names: List(Name),\n    pokemon_species: List(Resource),\n  )\n}\n\nPokemonColor(\n  id: Int,\n  name: String,\n  names: List(Name),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/color.PokemonColor\ntallgrass/pokemon/color PokemonColor","url":"tallgrass/pokemon/color.html#PokemonColor"},{"doc":"tallgrass/pokemon/color","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon color resources.\n\n # Example\n\n \n let result = color.new() |&gt; color.fetch()\n \nSynonyms:\ntallgrass/pokemon/color.fetch\ntallgrass/pokemon/color fetch","url":"tallgrass/pokemon/color.html#fetch"},{"doc":"tallgrass/pokemon/color","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokemonColor, Error)\n Fetches a pokemon color given the pokemon color ID.\n\n # Example\n\n \n let result = color.new() |&gt; color.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/color.fetch_by_id\ntallgrass/pokemon/color fetch_by_id","url":"tallgrass/pokemon/color.html#fetch_by_id"},{"doc":"tallgrass/pokemon/color","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokemonColor, Error)\n Fetches a pokemon color given the pokemon color name.\n\n # Example\n\n \n let result = color.new() |&gt; color.fetch_by_name(&quot;black&quot;)\n \nSynonyms:\ntallgrass/pokemon/color.fetch_by_name\ntallgrass/pokemon/color fetch_by_name","url":"tallgrass/pokemon/color.html#fetch_by_name"},{"doc":"tallgrass/pokemon/color","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokemonColor, Error)\n Fetches a pokemon color given a pokemon color resource.\n\n # Example\n\n \n let client = color.new()\n use res &lt;- result.try(client |&gt; color.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; color.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/color.fetch_resource\ntallgrass/pokemon/color fetch_resource","url":"tallgrass/pokemon/color.html#fetch_resource"},{"doc":"tallgrass/pokemon/color","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/color.new\ntallgrass/pokemon/color new","url":"tallgrass/pokemon/color.html#new"},{"doc":"tallgrass/pokemon/color","title":"tallgrass/pokemon/color","content":"","url":"tallgrass/pokemon/color.html"},{"doc":"tallgrass/pokemon/egg_group","title":"EggGroup","content":"pub type EggGroup {\n  EggGroup(\n    id: Int,\n    name: String,\n    names: List(Name),\n    pokemon_species: List(Resource),\n  )\n}\n\nEggGroup(\n  id: Int,\n  name: String,\n  names: List(Name),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/egg_group.EggGroup\ntallgrass/pokemon/egg_group EggGroup","url":"tallgrass/pokemon/egg_group.html#EggGroup"},{"doc":"tallgrass/pokemon/egg_group","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of egg group resources.\n\n # Example\n\n \n let result = egg_group.new() |&gt; egg_group.fetch()\n \nSynonyms:\ntallgrass/pokemon/egg_group.fetch\ntallgrass/pokemon/egg_group fetch","url":"tallgrass/pokemon/egg_group.html#fetch"},{"doc":"tallgrass/pokemon/egg_group","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(EggGroup, Error)\n Fetches a egg group given the egg group ID.\n\n # Example\n\n \n let result = egg_group.new() |&gt; egg_group.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/egg_group.fetch_by_id\ntallgrass/pokemon/egg_group fetch_by_id","url":"tallgrass/pokemon/egg_group.html#fetch_by_id"},{"doc":"tallgrass/pokemon/egg_group","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(EggGroup, Error)\n Fetches a egg group given the egg group name.\n\n # Example\n\n \n let result = egg_group.new() |&gt; egg_group.fetch_by_name(&quot;monster&quot;)\n \nSynonyms:\ntallgrass/pokemon/egg_group.fetch_by_name\ntallgrass/pokemon/egg_group fetch_by_name","url":"tallgrass/pokemon/egg_group.html#fetch_by_name"},{"doc":"tallgrass/pokemon/egg_group","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(EggGroup, Error)\n Fetches a egg group given a egg group resource.\n\n # Example\n\n \n let client = egg_group.new()\n use res &lt;- result.try(client |&gt; egg_group.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; egg_group.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/egg_group.fetch_resource\ntallgrass/pokemon/egg_group fetch_resource","url":"tallgrass/pokemon/egg_group.html#fetch_resource"},{"doc":"tallgrass/pokemon/egg_group","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/egg_group.new\ntallgrass/pokemon/egg_group new","url":"tallgrass/pokemon/egg_group.html#new"},{"doc":"tallgrass/pokemon/egg_group","title":"tallgrass/pokemon/egg_group","content":"","url":"tallgrass/pokemon/egg_group.html"},{"doc":"tallgrass/pokemon/form","title":"PokemonForm","content":"pub type PokemonForm {\n  PokemonForm(\n    id: Int,\n    name: String,\n    order: Int,\n    form_order: Int,\n    is_default: Bool,\n    is_battle_only: Bool,\n    is_mega: Bool,\n    form_name: String,\n    pokemon: Resource,\n    types: List(PokemonType),\n    version_group: Resource,\n  )\n}\n\nPokemonForm(\n  id: Int,\n  name: String,\n  order: Int,\n  form_order: Int,\n  is_default: Bool,\n  is_battle_only: Bool,\n  is_mega: Bool,\n  form_name: String,\n  pokemon: Resource,\n  types: List(PokemonType),\n  version_group: Resource,\n)\n\n\nSynonyms:\ntallgrass/pokemon/form.PokemonForm\ntallgrass/pokemon/form PokemonForm","url":"tallgrass/pokemon/form.html#PokemonForm"},{"doc":"tallgrass/pokemon/form","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon form resources.\n\n # Example\n\n \n let result = form.new() |&gt; form.fetch()\n \nSynonyms:\ntallgrass/pokemon/form.fetch\ntallgrass/pokemon/form fetch","url":"tallgrass/pokemon/form.html#fetch"},{"doc":"tallgrass/pokemon/form","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokemonForm, Error)\n Fetches a pokemon form given the pokemon form ID.\n\n # Example\n\n \n let result = form.new() |&gt; form.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/form.fetch_by_id\ntallgrass/pokemon/form fetch_by_id","url":"tallgrass/pokemon/form.html#fetch_by_id"},{"doc":"tallgrass/pokemon/form","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokemonForm, Error)\n Fetches a pokemon form given the pokemon form name.\n\n # Example\n\n \n let result = form.new() |&gt; form.fetch_by_name(&quot;arceus-bug&quot;)\n \nSynonyms:\ntallgrass/pokemon/form.fetch_by_name\ntallgrass/pokemon/form fetch_by_name","url":"tallgrass/pokemon/form.html#fetch_by_name"},{"doc":"tallgrass/pokemon/form","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokemonForm, Error)\n Fetches a pokemon form given a pokemon form resource.\n\n # Example\n\n \n let client = form.new()\n use res &lt;- result.try(client |&gt; form.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; form.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/form.fetch_resource\ntallgrass/pokemon/form fetch_resource","url":"tallgrass/pokemon/form.html#fetch_resource"},{"doc":"tallgrass/pokemon/form","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/form.new\ntallgrass/pokemon/form new","url":"tallgrass/pokemon/form.html#new"},{"doc":"tallgrass/pokemon/form","title":"tallgrass/pokemon/form","content":"","url":"tallgrass/pokemon/form.html"},{"doc":"tallgrass/pokemon/gender","title":"Gender","content":"pub type Gender {\n  Gender(\n    id: Int,\n    name: String,\n    pokemon_species_details: List(PokemonSpeciesGender),\n    required_for_evolution: List(Resource),\n  )\n}\n\nGender(\n  id: Int,\n  name: String,\n  pokemon_species_details: List(PokemonSpeciesGender),\n  required_for_evolution: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/gender.Gender\ntallgrass/pokemon/gender Gender","url":"tallgrass/pokemon/gender.html#Gender"},{"doc":"tallgrass/pokemon/gender","title":"PokemonSpeciesGender","content":"pub type PokemonSpeciesGender {\n  PokemonSpeciesGender(rate: Int, pokemon_species: Resource)\n}\n\nPokemonSpeciesGender(rate: Int, pokemon_species: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/gender.PokemonSpeciesGender\ntallgrass/pokemon/gender PokemonSpeciesGender","url":"tallgrass/pokemon/gender.html#PokemonSpeciesGender"},{"doc":"tallgrass/pokemon/gender","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon gender resources.\n\n # Example\n\n \n let result = gender.new() |&gt; gender.fetch()\n \nSynonyms:\ntallgrass/pokemon/gender.fetch\ntallgrass/pokemon/gender fetch","url":"tallgrass/pokemon/gender.html#fetch"},{"doc":"tallgrass/pokemon/gender","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Gender, Error)\n Fetches a pokemon gender given the pokemon gender ID.\n\n # Example\n\n \n let result = gender.new() |&gt; gender.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/gender.fetch_by_id\ntallgrass/pokemon/gender fetch_by_id","url":"tallgrass/pokemon/gender.html#fetch_by_id"},{"doc":"tallgrass/pokemon/gender","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Gender, Error)\n Fetches a pokemon gender given the pokemon gender name.\n\n # Example\n\n \n let result = gender.new() |&gt; gender.fetch_by_name(&quot;genderless&quot;)\n \nSynonyms:\ntallgrass/pokemon/gender.fetch_by_name\ntallgrass/pokemon/gender fetch_by_name","url":"tallgrass/pokemon/gender.html#fetch_by_name"},{"doc":"tallgrass/pokemon/gender","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Gender, Error)\n Fetches a pokemon gender given a pokemon gender resource.\n\n # Example\n\n \n let client = gender.new()\n use res &lt;- result.try(client |&gt; gender.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; gender.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/gender.fetch_resource\ntallgrass/pokemon/gender fetch_resource","url":"tallgrass/pokemon/gender.html#fetch_resource"},{"doc":"tallgrass/pokemon/gender","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/gender.new\ntallgrass/pokemon/gender new","url":"tallgrass/pokemon/gender.html#new"},{"doc":"tallgrass/pokemon/gender","title":"tallgrass/pokemon/gender","content":"","url":"tallgrass/pokemon/gender.html"},{"doc":"tallgrass/pokemon/growth_rate","title":"GrowthRate","content":"pub type GrowthRate {\n  GrowthRate(\n    id: Int,\n    name: String,\n    formula: String,\n    descriptions: List(Description),\n    levels: List(GrowthRateExperienceLevel),\n    pokemon_species: List(Resource),\n  )\n}\n\nGrowthRate(\n  id: Int,\n  name: String,\n  formula: String,\n  descriptions: List(Description),\n  levels: List(GrowthRateExperienceLevel),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/growth_rate.GrowthRate\ntallgrass/pokemon/growth_rate GrowthRate","url":"tallgrass/pokemon/growth_rate.html#GrowthRate"},{"doc":"tallgrass/pokemon/growth_rate","title":"GrowthRateExperienceLevel","content":"pub type GrowthRateExperienceLevel {\n  GrowthRateExperienceLevel(level: Int, experience: Int)\n}\n\nGrowthRateExperienceLevel(level: Int, experience: Int)\n\n\nSynonyms:\ntallgrass/pokemon/growth_rate.GrowthRateExperienceLevel\ntallgrass/pokemon/growth_rate GrowthRateExperienceLevel","url":"tallgrass/pokemon/growth_rate.html#GrowthRateExperienceLevel"},{"doc":"tallgrass/pokemon/growth_rate","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon growth rate resources.\n\n # Example\n\n \n let result = growth_rate.new() |&gt; growth_rate.fetch()\n \nSynonyms:\ntallgrass/pokemon/growth_rate.fetch\ntallgrass/pokemon/growth_rate fetch","url":"tallgrass/pokemon/growth_rate.html#fetch"},{"doc":"tallgrass/pokemon/growth_rate","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(GrowthRate, Error)\n Fetches a pokemon growth rate given the pokemon growth rate ID.\n\n # Example\n\n \n let result = growth_rate.new() |&gt; growth_rate.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/growth_rate.fetch_by_id\ntallgrass/pokemon/growth_rate fetch_by_id","url":"tallgrass/pokemon/growth_rate.html#fetch_by_id"},{"doc":"tallgrass/pokemon/growth_rate","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(GrowthRate, Error)\n Fetches a pokemon growth rate given the pokemon growth rate name.\n\n # Example\n\n \n let result = growth_rate.new() |&gt; growth_rate.fetch_by_name(&quot;slow&quot;)\n \nSynonyms:\ntallgrass/pokemon/growth_rate.fetch_by_name\ntallgrass/pokemon/growth_rate fetch_by_name","url":"tallgrass/pokemon/growth_rate.html#fetch_by_name"},{"doc":"tallgrass/pokemon/growth_rate","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(GrowthRate, Error)\n Fetches a pokemon growth rate given a pokemon growth rate resource.\n\n # Example\n\n \n let client = growth_rate.new()\n use res &lt;- result.try(client |&gt; growth_rate.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; growth_rate.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/growth_rate.fetch_resource\ntallgrass/pokemon/growth_rate fetch_resource","url":"tallgrass/pokemon/growth_rate.html#fetch_resource"},{"doc":"tallgrass/pokemon/growth_rate","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/growth_rate.new\ntallgrass/pokemon/growth_rate new","url":"tallgrass/pokemon/growth_rate.html#new"},{"doc":"tallgrass/pokemon/growth_rate","title":"tallgrass/pokemon/growth_rate","content":"","url":"tallgrass/pokemon/growth_rate.html"},{"doc":"tallgrass/pokemon/habitat","title":"Habitat","content":"pub type Habitat {\n  Habitat(\n    id: Int,\n    name: String,\n    names: List(Name),\n    pokemon_species: List(Resource),\n  )\n}\n\nHabitat(\n  id: Int,\n  name: String,\n  names: List(Name),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/habitat.Habitat\ntallgrass/pokemon/habitat Habitat","url":"tallgrass/pokemon/habitat.html#Habitat"},{"doc":"tallgrass/pokemon/habitat","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon habitat resources.\n\n # Example\n\n \n let result = habitat.new() |&gt; habitat.fetch()\n \nSynonyms:\ntallgrass/pokemon/habitat.fetch\ntallgrass/pokemon/habitat fetch","url":"tallgrass/pokemon/habitat.html#fetch"},{"doc":"tallgrass/pokemon/habitat","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Habitat, Error)\n Fetches a pokemon habitat given the pokemon habitat ID.\n\n # Example\n\n \n let result = habitat.new() |&gt; habitat.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/habitat.fetch_by_id\ntallgrass/pokemon/habitat fetch_by_id","url":"tallgrass/pokemon/habitat.html#fetch_by_id"},{"doc":"tallgrass/pokemon/habitat","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Habitat, Error)\n Fetches a pokemon habitat given the pokemon habitat name.\n\n # Example\n\n \n let result = habitat.new() |&gt; habitat.fetch_by_name(&quot;cave&quot;)\n \nSynonyms:\ntallgrass/pokemon/habitat.fetch_by_name\ntallgrass/pokemon/habitat fetch_by_name","url":"tallgrass/pokemon/habitat.html#fetch_by_name"},{"doc":"tallgrass/pokemon/habitat","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Habitat, Error)\n Fetches a pokemon habitat given a pokemon habitat resource.\n\n # Example\n\n \n let client = habitat.new()\n use res &lt;- result.try(client |&gt; habitat.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; habitat.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/habitat.fetch_resource\ntallgrass/pokemon/habitat fetch_resource","url":"tallgrass/pokemon/habitat.html#fetch_resource"},{"doc":"tallgrass/pokemon/habitat","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/habitat.new\ntallgrass/pokemon/habitat new","url":"tallgrass/pokemon/habitat.html#new"},{"doc":"tallgrass/pokemon/habitat","title":"tallgrass/pokemon/habitat","content":"","url":"tallgrass/pokemon/habitat.html"},{"doc":"tallgrass/pokemon/location_area","title":"EncounterDetail","content":"pub type EncounterDetail {\n  EncounterDetail(\n    min_level: Int,\n    max_level: Int,\n    chance: Int,\n    method: Resource,\n    condition_values: List(Resource),\n  )\n}\n\nEncounterDetail(\n  min_level: Int,\n  max_level: Int,\n  chance: Int,\n  method: Resource,\n  condition_values: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/location_area.EncounterDetail\ntallgrass/pokemon/location_area EncounterDetail","url":"tallgrass/pokemon/location_area.html#EncounterDetail"},{"doc":"tallgrass/pokemon/location_area","title":"PokemonLocationArea","content":"pub type PokemonLocationArea {\n  PokemonLocationArea(\n    location_area: Resource,\n    version_details: List(VersionDetail),\n  )\n}\n\nPokemonLocationArea(\n  location_area: Resource,\n  version_details: List(VersionDetail),\n)\n\n\nSynonyms:\ntallgrass/pokemon/location_area.PokemonLocationArea\ntallgrass/pokemon/location_area PokemonLocationArea","url":"tallgrass/pokemon/location_area.html#PokemonLocationArea"},{"doc":"tallgrass/pokemon/location_area","title":"VersionDetail","content":"pub type VersionDetail {\n  VersionDetail(\n    max_chance: Int,\n    encounter_details: List(EncounterDetail),\n    version: Resource,\n  )\n}\n\nVersionDetail(\n  max_chance: Int,\n  encounter_details: List(EncounterDetail),\n  version: Resource,\n)\n\n\nSynonyms:\ntallgrass/pokemon/location_area.VersionDetail\ntallgrass/pokemon/location_area VersionDetail","url":"tallgrass/pokemon/location_area.html#VersionDetail"},{"doc":"tallgrass/pokemon/location_area","title":"fetch_for_pokemon_with_id","content":"pub fn fetch_for_pokemon_with_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(List(PokemonLocationArea), Error)\n Fetches a pokemon location area given the pokemon ID.\n\n # Example\n\n \n let result = location_area.new() |&gt; location_area.fetch_for_pokemon_with_id(1)\n \nSynonyms:\ntallgrass/pokemon/location_area.fetch_for_pokemon_with_id\ntallgrass/pokemon/location_area fetch_for_pokemon_with_id","url":"tallgrass/pokemon/location_area.html#fetch_for_pokemon_with_id"},{"doc":"tallgrass/pokemon/location_area","title":"fetch_for_pokemon_with_name","content":"pub fn fetch_for_pokemon_with_name(\n  client: Client,\n  name: String,\n) -&gt; Result(List(PokemonLocationArea), Error)\n Fetches a pokemon location area given the pokemon name.\n\n # Example\n\n \n let result = location_area.new() |&gt; location_area.fetch_for_pokemon_with_name(&quot;bulbasaur&quot;)\n \nSynonyms:\ntallgrass/pokemon/location_area.fetch_for_pokemon_with_name\ntallgrass/pokemon/location_area fetch_for_pokemon_with_name","url":"tallgrass/pokemon/location_area.html#fetch_for_pokemon_with_name"},{"doc":"tallgrass/pokemon/location_area","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/location_area.new\ntallgrass/pokemon/location_area new","url":"tallgrass/pokemon/location_area.html#new"},{"doc":"tallgrass/pokemon/location_area","title":"tallgrass/pokemon/location_area","content":"","url":"tallgrass/pokemon/location_area.html"},{"doc":"tallgrass/pokemon/nature","title":"MoveBattleStylePreference","content":"pub type MoveBattleStylePreference {\n  MoveBattleStylePreference(\n    low_hp_preference: Int,\n    high_hp_preference: Int,\n    move_battle_style: Resource,\n  )\n}\n\nMoveBattleStylePreference(\n  low_hp_preference: Int,\n  high_hp_preference: Int,\n  move_battle_style: Resource,\n)\n\n\nSynonyms:\ntallgrass/pokemon/nature.MoveBattleStylePreference\ntallgrass/pokemon/nature MoveBattleStylePreference","url":"tallgrass/pokemon/nature.html#MoveBattleStylePreference"},{"doc":"tallgrass/pokemon/nature","title":"Nature","content":"pub type Nature {\n  Nature(\n    id: Int,\n    name: String,\n    decreased_stat: Option(Resource),\n    increased_stat: Option(Resource),\n    likes_flavor: Option(Resource),\n    hates_flavor: Option(Resource),\n    pokeathlon_stat_changes: List(NatureStatChange),\n    move_battle_style_preferences: List(\n      MoveBattleStylePreference,\n    ),\n    names: List(Name),\n  )\n}\n\nNature(\n  id: Int,\n  name: String,\n  decreased_stat: Option(Resource),\n  increased_stat: Option(Resource),\n  likes_flavor: Option(Resource),\n  hates_flavor: Option(Resource),\n  pokeathlon_stat_changes: List(NatureStatChange),\n  move_battle_style_preferences: List(MoveBattleStylePreference),\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/pokemon/nature.Nature\ntallgrass/pokemon/nature Nature","url":"tallgrass/pokemon/nature.html#Nature"},{"doc":"tallgrass/pokemon/nature","title":"NatureStatChange","content":"pub type NatureStatChange {\n  NatureStatChange(max_change: Int, pokeathlon_stat: Resource)\n}\n\nNatureStatChange(max_change: Int, pokeathlon_stat: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/nature.NatureStatChange\ntallgrass/pokemon/nature NatureStatChange","url":"tallgrass/pokemon/nature.html#NatureStatChange"},{"doc":"tallgrass/pokemon/nature","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon nature resources.\n\n # Example\n\n \n let result = nature.new() |&gt; nature.fetch()\n \nSynonyms:\ntallgrass/pokemon/nature.fetch\ntallgrass/pokemon/nature fetch","url":"tallgrass/pokemon/nature.html#fetch"},{"doc":"tallgrass/pokemon/nature","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Nature, Error)\n Fetches a pokemon nature given the pokemon nature ID.\n\n # Example\n\n \n let result = nature.new() |&gt; nature.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/nature.fetch_by_id\ntallgrass/pokemon/nature fetch_by_id","url":"tallgrass/pokemon/nature.html#fetch_by_id"},{"doc":"tallgrass/pokemon/nature","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Nature, Error)\n Fetches a pokemon nature given the pokemon nature name.\n\n # Example\n\n \n let result = nature.new() |&gt; nature.fetch_by_name(&quot;bold&quot;)\n \nSynonyms:\ntallgrass/pokemon/nature.fetch_by_name\ntallgrass/pokemon/nature fetch_by_name","url":"tallgrass/pokemon/nature.html#fetch_by_name"},{"doc":"tallgrass/pokemon/nature","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Nature, Error)\n Fetches a pokemon nature given a pokemon nature resource.\n\n # Example\n\n \n let client = nature.new()\n use res &lt;- result.try(client |&gt; nature.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; nature.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/nature.fetch_resource\ntallgrass/pokemon/nature fetch_resource","url":"tallgrass/pokemon/nature.html#fetch_resource"},{"doc":"tallgrass/pokemon/nature","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/nature.new\ntallgrass/pokemon/nature new","url":"tallgrass/pokemon/nature.html#new"},{"doc":"tallgrass/pokemon/nature","title":"tallgrass/pokemon/nature","content":"","url":"tallgrass/pokemon/nature.html"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"NaturePokeathlonStatAffect","content":"pub type NaturePokeathlonStatAffect {\n  NaturePokeathlonStatAffect(max_change: Int, nature: Resource)\n}\n\nNaturePokeathlonStatAffect(max_change: Int, nature: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.NaturePokeathlonStatAffect\ntallgrass/pokemon/pokeathlon_stat NaturePokeathlonStatAffect","url":"tallgrass/pokemon/pokeathlon_stat.html#NaturePokeathlonStatAffect"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"NaturePokeathlonStatAffectSets","content":"pub type NaturePokeathlonStatAffectSets {\n  NaturePokeathlonStatAffectSets(\n    increase: List(NaturePokeathlonStatAffect),\n    decrease: List(NaturePokeathlonStatAffect),\n  )\n}\n\nNaturePokeathlonStatAffectSets(\n  increase: List(NaturePokeathlonStatAffect),\n  decrease: List(NaturePokeathlonStatAffect),\n)\n\n\nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.NaturePokeathlonStatAffectSets\ntallgrass/pokemon/pokeathlon_stat NaturePokeathlonStatAffectSets","url":"tallgrass/pokemon/pokeathlon_stat.html#NaturePokeathlonStatAffectSets"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"PokeathlonStat","content":"pub type PokeathlonStat {\n  PokeathlonStat(\n    id: Int,\n    name: String,\n    names: List(Name),\n    affecting_natures: NaturePokeathlonStatAffectSets,\n  )\n}\n\nPokeathlonStat(\n  id: Int,\n  name: String,\n  names: List(Name),\n  affecting_natures: NaturePokeathlonStatAffectSets,\n)\n\n\nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.PokeathlonStat\ntallgrass/pokemon/pokeathlon_stat PokeathlonStat","url":"tallgrass/pokemon/pokeathlon_stat.html#PokeathlonStat"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokeathlon stat resources.\n\n # Example\n\n \n let result = pokeathlon_stat.new() |&gt; pokeathlon_stat.fetch()\n \nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.fetch\ntallgrass/pokemon/pokeathlon_stat fetch","url":"tallgrass/pokemon/pokeathlon_stat.html#fetch"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokeathlonStat, Error)\n Fetches a pokeathlon stat given the pokeathlon stat ID.\n\n # Example\n\n \n let result = pokeathlon_stat.new() |&gt; pokeathlon_stat.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.fetch_by_id\ntallgrass/pokemon/pokeathlon_stat fetch_by_id","url":"tallgrass/pokemon/pokeathlon_stat.html#fetch_by_id"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokeathlonStat, Error)\n Fetches a pokeathlon stat given the pokeathlon stat name.\n\n # Example\n\n \n let result = pokeathlon_stat.new() |&gt; pokeathlon_stat.fetch_by_name(&quot;skill&quot;)\n \nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.fetch_by_name\ntallgrass/pokemon/pokeathlon_stat fetch_by_name","url":"tallgrass/pokemon/pokeathlon_stat.html#fetch_by_name"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokeathlonStat, Error)\n Fetches a pokeathlon stat given a pokeathlon stat resource.\n\n # Example\n\n \n let client = pokeathlon_stat.new()\n use res &lt;- result.try(client |&gt; pokeathlon_stat.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pokeathlon_stat.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.fetch_resource\ntallgrass/pokemon/pokeathlon_stat fetch_resource","url":"tallgrass/pokemon/pokeathlon_stat.html#fetch_resource"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/pokeathlon_stat.new\ntallgrass/pokemon/pokeathlon_stat new","url":"tallgrass/pokemon/pokeathlon_stat.html#new"},{"doc":"tallgrass/pokemon/pokeathlon_stat","title":"tallgrass/pokemon/pokeathlon_stat","content":"","url":"tallgrass/pokemon/pokeathlon_stat.html"},{"doc":"tallgrass/pokemon/pokemon_type","title":"PokemonType","content":"pub type PokemonType {\n  PokemonType(\n    id: Int,\n    name: String,\n    damage_relations: PokemonTypeDamageRelations,\n    past_damage_relations: List(PokemonTypeDamageRelationsPast),\n    game_indices: List(GenerationGameIndex),\n    generation: Resource,\n    move_damage_class: Resource,\n    names: List(Name),\n    pokemon: List(TypePokemon),\n    moves: List(Resource),\n  )\n}\n\nPokemonType(\n  id: Int,\n  name: String,\n  damage_relations: PokemonTypeDamageRelations,\n  past_damage_relations: List(PokemonTypeDamageRelationsPast),\n  game_indices: List(GenerationGameIndex),\n  generation: Resource,\n  move_damage_class: Resource,\n  names: List(Name),\n  pokemon: List(TypePokemon),\n  moves: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/pokemon_type.PokemonType\ntallgrass/pokemon/pokemon_type PokemonType","url":"tallgrass/pokemon/pokemon_type.html#PokemonType"},{"doc":"tallgrass/pokemon/pokemon_type","title":"PokemonTypeDamageRelations","content":"pub type PokemonTypeDamageRelations {\n  PokemonTypeDamageRelations(\n    no_damage_to: List(Resource),\n    half_damage_to: List(Resource),\n    double_damage_to: List(Resource),\n    no_damage_from: List(Resource),\n    half_damage_from: List(Resource),\n    double_damage_from: List(Resource),\n  )\n}\n\nPokemonTypeDamageRelations(\n  no_damage_to: List(Resource),\n  half_damage_to: List(Resource),\n  double_damage_to: List(Resource),\n  no_damage_from: List(Resource),\n  half_damage_from: List(Resource),\n  double_damage_from: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/pokemon_type.PokemonTypeDamageRelations\ntallgrass/pokemon/pokemon_type PokemonTypeDamageRelations","url":"tallgrass/pokemon/pokemon_type.html#PokemonTypeDamageRelations"},{"doc":"tallgrass/pokemon/pokemon_type","title":"PokemonTypeDamageRelationsPast","content":"pub type PokemonTypeDamageRelationsPast {\n  PokemonTypeDamageRelationsPast(\n    generation: Resource,\n    damage_relations: PokemonTypeDamageRelations,\n  )\n}\n\nPokemonTypeDamageRelationsPast(\n  generation: Resource,\n  damage_relations: PokemonTypeDamageRelations,\n)\n\n\nSynonyms:\ntallgrass/pokemon/pokemon_type.PokemonTypeDamageRelationsPast\ntallgrass/pokemon/pokemon_type PokemonTypeDamageRelationsPast","url":"tallgrass/pokemon/pokemon_type.html#PokemonTypeDamageRelationsPast"},{"doc":"tallgrass/pokemon/pokemon_type","title":"TypePokemon","content":"pub type TypePokemon {\n  TypePokemon(slot: Int, pokemon: Resource)\n}\n\nTypePokemon(slot: Int, pokemon: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/pokemon_type.TypePokemon\ntallgrass/pokemon/pokemon_type TypePokemon","url":"tallgrass/pokemon/pokemon_type.html#TypePokemon"},{"doc":"tallgrass/pokemon/pokemon_type","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon type resources.\n\n # Example\n\n \n let result = pokemon_type.new() |&gt; pokemon_type.fetch()\n \nSynonyms:\ntallgrass/pokemon/pokemon_type.fetch\ntallgrass/pokemon/pokemon_type fetch","url":"tallgrass/pokemon/pokemon_type.html#fetch"},{"doc":"tallgrass/pokemon/pokemon_type","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokemonType, Error)\n Fetches a pokemon type given the pokemon type ID.\n\n # Example\n\n \n let result = pokemon_type.new() |&gt; pokemon_type.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/pokemon_type.fetch_by_id\ntallgrass/pokemon/pokemon_type fetch_by_id","url":"tallgrass/pokemon/pokemon_type.html#fetch_by_id"},{"doc":"tallgrass/pokemon/pokemon_type","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokemonType, Error)\n Fetches a pokemon type given the pokemon type name.\n\n # Example\n\n \n let result = pokemon_type.new() |&gt; pokemon_type.fetch_by_name(&quot;fairy&quot;)\n \nSynonyms:\ntallgrass/pokemon/pokemon_type.fetch_by_name\ntallgrass/pokemon/pokemon_type fetch_by_name","url":"tallgrass/pokemon/pokemon_type.html#fetch_by_name"},{"doc":"tallgrass/pokemon/pokemon_type","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokemonType, Error)\n Fetches a pokemon type given a pokemon type resource.\n\n # Example\n\n \n let client = pokemon_type.new()\n use res &lt;- result.try(client |&gt; pokemon_type.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; pokemon_type.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/pokemon_type.fetch_resource\ntallgrass/pokemon/pokemon_type fetch_resource","url":"tallgrass/pokemon/pokemon_type.html#fetch_resource"},{"doc":"tallgrass/pokemon/pokemon_type","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/pokemon_type.new\ntallgrass/pokemon/pokemon_type new","url":"tallgrass/pokemon/pokemon_type.html#new"},{"doc":"tallgrass/pokemon/pokemon_type","title":"tallgrass/pokemon/pokemon_type","content":"","url":"tallgrass/pokemon/pokemon_type.html"},{"doc":"tallgrass/pokemon/shape","title":"PokemonShape","content":"pub type PokemonShape {\n  PokemonShape(\n    id: Int,\n    name: String,\n    names: List(Name),\n    awesome_names: List(Name),\n    pokemon_species: List(Resource),\n  )\n}\n\nPokemonShape(\n  id: Int,\n  name: String,\n  names: List(Name),\n  awesome_names: List(Name),\n  pokemon_species: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/shape.PokemonShape\ntallgrass/pokemon/shape PokemonShape","url":"tallgrass/pokemon/shape.html#PokemonShape"},{"doc":"tallgrass/pokemon/shape","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon shape resources.\n\n # Example\n\n \n let result = shape.new() |&gt; shape.fetch()\n \nSynonyms:\ntallgrass/pokemon/shape.fetch\ntallgrass/pokemon/shape fetch","url":"tallgrass/pokemon/shape.html#fetch"},{"doc":"tallgrass/pokemon/shape","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokemonShape, Error)\n Fetches a pokemon shape given the pokemon shape ID.\n\n # Example\n\n \n let result = shape.new() |&gt; shape.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/shape.fetch_by_id\ntallgrass/pokemon/shape fetch_by_id","url":"tallgrass/pokemon/shape.html#fetch_by_id"},{"doc":"tallgrass/pokemon/shape","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokemonShape, Error)\n Fetches a pokemon shape given the pokemon shape name.\n\n # Example\n\n \n let result = shape.new() |&gt; shape.fetch_by_name(&quot;ball&quot;)\n \nSynonyms:\ntallgrass/pokemon/shape.fetch_by_name\ntallgrass/pokemon/shape fetch_by_name","url":"tallgrass/pokemon/shape.html#fetch_by_name"},{"doc":"tallgrass/pokemon/shape","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokemonShape, Error)\n Fetches a pokemon shape given a pokemon shape resource.\n\n # Example\n\n \n let client = shape.new()\n use res &lt;- result.try(client |&gt; shape.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; shape.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/shape.fetch_resource\ntallgrass/pokemon/shape fetch_resource","url":"tallgrass/pokemon/shape.html#fetch_resource"},{"doc":"tallgrass/pokemon/shape","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/shape.new\ntallgrass/pokemon/shape new","url":"tallgrass/pokemon/shape.html#new"},{"doc":"tallgrass/pokemon/shape","title":"tallgrass/pokemon/shape","content":"","url":"tallgrass/pokemon/shape.html"},{"doc":"tallgrass/pokemon/species","title":"PokemonSpecies","content":"pub type PokemonSpecies {\n  PokemonSpecies(\n    id: Int,\n    name: String,\n    order: Int,\n    gender_rate: Int,\n    capture_rate: Int,\n    base_happiness: Int,\n    is_baby: Bool,\n    is_legendary: Bool,\n    is_mythical: Bool,\n    hatch_counter: Int,\n    has_gender_differences: Bool,\n    forms_switchable: Bool,\n    growth_rate: Resource,\n    egg_groups: List(Resource),\n    color: Resource,\n    shape: Resource,\n    evolves_from_species: Resource,\n    generation: Resource,\n    names: List(Name),\n  )\n}\n\nPokemonSpecies(\n  id: Int,\n  name: String,\n  order: Int,\n  gender_rate: Int,\n  capture_rate: Int,\n  base_happiness: Int,\n  is_baby: Bool,\n  is_legendary: Bool,\n  is_mythical: Bool,\n  hatch_counter: Int,\n  has_gender_differences: Bool,\n  forms_switchable: Bool,\n  growth_rate: Resource,\n  egg_groups: List(Resource),\n  color: Resource,\n  shape: Resource,\n  evolves_from_species: Resource,\n  generation: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/pokemon/species.PokemonSpecies\ntallgrass/pokemon/species PokemonSpecies","url":"tallgrass/pokemon/species.html#PokemonSpecies"},{"doc":"tallgrass/pokemon/species","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon species resources.\n\n # Example\n\n \n let result = species.new() |&gt; species.fetch()\n \nSynonyms:\ntallgrass/pokemon/species.fetch\ntallgrass/pokemon/species fetch","url":"tallgrass/pokemon/species.html#fetch"},{"doc":"tallgrass/pokemon/species","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(PokemonSpecies, Error)\n Fetches a pokemon species given the pokemon species ID.\n\n # Example\n\n \n let result = species.new() |&gt; species.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/species.fetch_by_id\ntallgrass/pokemon/species fetch_by_id","url":"tallgrass/pokemon/species.html#fetch_by_id"},{"doc":"tallgrass/pokemon/species","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(PokemonSpecies, Error)\n Fetches a pokemon species given the pokemon species name.\n\n # Example\n\n \n let result = species.new() |&gt; species.fetch_by_name(&quot;ditto&quot;)\n \nSynonyms:\ntallgrass/pokemon/species.fetch_by_name\ntallgrass/pokemon/species fetch_by_name","url":"tallgrass/pokemon/species.html#fetch_by_name"},{"doc":"tallgrass/pokemon/species","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(PokemonSpecies, Error)\n Fetches a pokemon species given a pokemon species resource.\n\n # Example\n\n \n let client = species.new()\n use res &lt;- result.try(client |&gt; species.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; species.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/species.fetch_resource\ntallgrass/pokemon/species fetch_resource","url":"tallgrass/pokemon/species.html#fetch_resource"},{"doc":"tallgrass/pokemon/species","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/species.new\ntallgrass/pokemon/species new","url":"tallgrass/pokemon/species.html#new"},{"doc":"tallgrass/pokemon/species","title":"tallgrass/pokemon/species","content":"","url":"tallgrass/pokemon/species.html"},{"doc":"tallgrass/pokemon/stat","title":"MoveStatAffect","content":"pub type MoveStatAffect {\n  MoveStatAffect(change: Int, move: Resource)\n}\n\nMoveStatAffect(change: Int, move: Resource)\n\n\nSynonyms:\ntallgrass/pokemon/stat.MoveStatAffect\ntallgrass/pokemon/stat MoveStatAffect","url":"tallgrass/pokemon/stat.html#MoveStatAffect"},{"doc":"tallgrass/pokemon/stat","title":"MoveStatAffectSets","content":"pub type MoveStatAffectSets {\n  MoveStatAffectSets(\n    increase: List(MoveStatAffect),\n    decrease: List(MoveStatAffect),\n  )\n}\n\nMoveStatAffectSets(\n  increase: List(MoveStatAffect),\n  decrease: List(MoveStatAffect),\n)\n\n\nSynonyms:\ntallgrass/pokemon/stat.MoveStatAffectSets\ntallgrass/pokemon/stat MoveStatAffectSets","url":"tallgrass/pokemon/stat.html#MoveStatAffectSets"},{"doc":"tallgrass/pokemon/stat","title":"NatureStatAffectSets","content":"pub type NatureStatAffectSets {\n  NatureStatAffectSets(\n    increase: List(Resource),\n    decrease: List(Resource),\n  )\n}\n\nNatureStatAffectSets(\n  increase: List(Resource),\n  decrease: List(Resource),\n)\n\n\nSynonyms:\ntallgrass/pokemon/stat.NatureStatAffectSets\ntallgrass/pokemon/stat NatureStatAffectSets","url":"tallgrass/pokemon/stat.html#NatureStatAffectSets"},{"doc":"tallgrass/pokemon/stat","title":"Stat","content":"pub type Stat {\n  Stat(\n    id: Int,\n    name: String,\n    game_index: Int,\n    is_battle_only: Bool,\n    affecting_moves: MoveStatAffectSets,\n    affecting_natures: NatureStatAffectSets,\n    move_damage_class: Resource,\n    names: List(Name),\n  )\n}\n\nStat(\n  id: Int,\n  name: String,\n  game_index: Int,\n  is_battle_only: Bool,\n  affecting_moves: MoveStatAffectSets,\n  affecting_natures: NatureStatAffectSets,\n  move_damage_class: Resource,\n  names: List(Name),\n)\n\n\nSynonyms:\ntallgrass/pokemon/stat.Stat\ntallgrass/pokemon/stat Stat","url":"tallgrass/pokemon/stat.html#Stat"},{"doc":"tallgrass/pokemon/stat","title":"fetch","content":"pub fn fetch(client: Client) -&gt; Result(PaginatedResource, Error)\n Fetches a paginated list of pokemon stat resources.\n\n # Example\n\n \n let result = stat.new() |&gt; stat.fetch()\n \nSynonyms:\ntallgrass/pokemon/stat.fetch\ntallgrass/pokemon/stat fetch","url":"tallgrass/pokemon/stat.html#fetch"},{"doc":"tallgrass/pokemon/stat","title":"fetch_by_id","content":"pub fn fetch_by_id(\n  client: Client,\n  id: Int,\n) -&gt; Result(Stat, Error)\n Fetches a pokemon stat given the pokemon stat ID.\n\n # Example\n\n \n let result = stat.new() |&gt; stat.fetch_by_id(1)\n \nSynonyms:\ntallgrass/pokemon/stat.fetch_by_id\ntallgrass/pokemon/stat fetch_by_id","url":"tallgrass/pokemon/stat.html#fetch_by_id"},{"doc":"tallgrass/pokemon/stat","title":"fetch_by_name","content":"pub fn fetch_by_name(\n  client: Client,\n  name: String,\n) -&gt; Result(Stat, Error)\n Fetches a pokemon stat given the pokemon stat name.\n\n # Example\n\n \n let result = stat.new() |&gt; stat.fetch_by_name(&quot;attack&quot;)\n \nSynonyms:\ntallgrass/pokemon/stat.fetch_by_name\ntallgrass/pokemon/stat fetch_by_name","url":"tallgrass/pokemon/stat.html#fetch_by_name"},{"doc":"tallgrass/pokemon/stat","title":"fetch_resource","content":"pub fn fetch_resource(\n  client: Client,\n  resource: Resource,\n) -&gt; Result(Stat, Error)\n Fetches a pokemon stat given a pokemon stat resource.\n\n # Example\n\n \n let client = stat.new()\n use res &lt;- result.try(client |&gt; stat.fetch())\n let assert Ok(first) = res.results |&gt; list.first\n client |&gt; stat.fetch_resource(first)\n \nSynonyms:\ntallgrass/pokemon/stat.fetch_resource\ntallgrass/pokemon/stat fetch_resource","url":"tallgrass/pokemon/stat.html#fetch_resource"},{"doc":"tallgrass/pokemon/stat","title":"new","content":"pub fn new() -&gt; Client\n Creates a new Client.\n This is a re-export of client.new, for the sake of convenience.\nSynonyms:\ntallgrass/pokemon/stat.new\ntallgrass/pokemon/stat new","url":"tallgrass/pokemon/stat.html#new"},{"doc":"tallgrass/pokemon/stat","title":"tallgrass/pokemon/stat","content":"","url":"tallgrass/pokemon/stat.html"}]);